package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@$!`0````````````,`*``!````W!@``#0```#,T0````(`!30`(``)
M`"@`'``;``$``'#PR0``\,D``/#)```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````#\R0``_,D```4```````$`
M`0```'C-``!XS0$`>,T!`.0"``#\$@``!@```````0`"````A,T``(3-`0"$
MS0$`*`$``"@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D>,T`
M`'C-`0!XS0$`B`(``(@"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`UYL+C)_:@6W,-='Q72^=7%>L0\D1````40````@````(`````9`0!"5`
M!(`H@``!H(90@(`!```+*`2-.*`218H$"`A1````4@```%8```!;````7```
M`&,```!D````90```&<```!H`````````&H```!K````;````&X`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M````````````$!,````````#``L``````(#-`0```````P`4`,T"````````
M`````!(```![`P`````````````2````3P,`````````````(@```)0#````
M`````````!$````Y!``````````````2````$0``````````````(````#X"
M`````````````!(````A`P`````````````2````;`,`````````````$@``
M`"4!`````````````!(```"L`P`````````````1````R```````````````
M$@```.@"`````````````!(```"7`0`````````````2````U`(`````````
M````$@```)@``````````````!(````@`0`````````````2````[P(`````
M````````$@```'X"`````````````!(```!-`@`````````````2````CP(`
M````````````$@```)P"`````````````!(````5`0`````````````1````
M>P$`````````````$@```/<``````````````!$```!)`0`````````````2
M````*`,`````````````$@```!H#`````````````!$````Q`P``````````
M```2````U@``````````````$@```,4!`````````````!(````V`@``````
M```````2````L@$`````````````$@````@#`````````````!(````>`@``
M```````````2````O@$`````````````$@```((#`````````````!(```!7
M`0`````````````2````+0``````````````(````+$"`````````````!(`
M``!?`@`````````````2````OP(`````````````$@```-`!````````````
M`!$```!X```````````````2````/@,`````````````$@```*<`````````
M`````!(````E`@`````````````2````7@,`````````````$@```+,`````
M`````````!(```!L`@`````````````2````<`$`````````````$@```)8"
M`````````````!(```#&`@`````````````2````-@$`````````````$@``
M`&H``````````````!(````J`0`````````````2````IP$`````````````
M$@```-H"`````````````!(````$`0`````````````2````J@(`````````
M````$@```'0#`````````````!(```"X`@`````````````2````B0$`````
M````````$@```(<``````````````!(```"5`P`````````````A````/```
M````````````(````$4#`````````````!(```#H```````````````2````
M9P$`````````````$@```%```````````````"````"6`P`````````````1
M````$`,`````````````$@```&0"`````````````!(```"D`@``````````
M```2````&`(`````````````$@```/T"`````````````!(```!U`@``````
M```````2````!`(`````````````$@```.X#``!TX`$``````!``&`!"!```
M%(@``(`````2``T`$`0``#")````````$@`.`&<$``!\>```:`L``!(`#0"/
M`P``.!8``*0"```2``T`%@0``/AO```$````$@`-`-\#``!<T`$``````!``
M&`#5!```_&\``+0"```2``T`SP0``!`3````````$@`+``(%``#D@P``,`0`
M`!(`#0#3`P``7-`!```````0`!@`3@0``+!R```H````$@`-`($$```\B0``
M!````!$`#P`!!```=.`!```````0`!@`^0,``'3@`0``````$``8`,T$```\
M;@``5````!(`#0#B!```&'<``&0!```2``T`]`0``%AV``"D````$@`-`'0$
M````T`$``````!``%P!;!```V'(``#P!```2``T`S`,``%S0`0``````$``7
M`+8$``!8T`$`!````!$`%P`&!```+(D```0````2``T`I@0``,2(``!H````
M$@`-`'H$``#<&````````!(`#0!V!````-`!```````@`!<`)P0``/QV```<
M````$@`-`.T#``!TX`$``````!``&`"0!```!&\``/0````2``T`P`0``!1T
M``!$`@``$@`-``!L:6)P97)L+G-O+C4N,C0`7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?
M<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R
M;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!0
M97)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``
M4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V
M7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E
M<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN
M<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V
M-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S
M`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@N
M<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!L:6)C<GEP="YS;RXQ`%]E9&%T80!?
M7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`
M7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D
M:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET
M`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`1TQ)0D-?,BXT``````````(``@`"``(``@````,``@`"``(`
M!`````(````"```````"``(``@`"``(````````````"``(``@```````P``
M``(``P`"``(```````(``@`"```````"`````P`"`````@````(``@``````
M``````(````"``(``@```````@````(``````````@`"``(``@`#``(``@`#
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0">`P``$````"`````4:6D-```$`!@%````
M`````0`!`/0!```0````(````!1I:0T```,`&`4````````!``$`0P(``!``
M````````%&EI#0```@`8!0```````'C-`0`7````?,T!`!<```"XSP$`%P``
M`-S/`0`7````Y,\!`!<```#LSP$`%P````30`0`7````#-`!`!<````0T`$`
M%P```!30`0`7````&-`!`!<````<T`$`%P```"#0`0`7````*-`!`!<````L
MT`$`%P```#30`0`7````.-`!`!<````\T`$`%P```$#0`0`7````1-`!`!<`
M``!,T`$`%P```%#0`0`7````6-`!`!<```"\SP$`%04``,#/`0`5"```Q,\!
M`!4-``#(SP$`%1```,S/`0`5&0``T,\!`!4;``#4SP$`%1X``-C/`0`5*0``
MX,\!`!4M``#HSP$`%3@``/#/`0`50@``],\!`!5$``#XSP$`%4@``/S/`0`5
M20``N,X!`!8#``"\S@$`%@0``,#.`0`6!0``Q,X!`!8'``#(S@$`%@D``,S.
M`0`6"@``T,X!`!8+``#4S@$`%@P``-C.`0`6#@``W,X!`!8/``#@S@$`%A$`
M`.3.`0`6$@``Z,X!`!83``#LS@$`%A0``/#.`0`6%0``],X!`!86``#XS@$`
M%A<``/S.`0`6&````,\!`!8:```$SP$`%AP```C/`0`6'0``#,\!`!8?```0
MSP$`%B```!3/`0`6(0``&,\!`!8B```<SP$`%B,``"#/`0`6)```),\!`!8E
M```HSP$`%B8``"S/`0`6)P``,,\!`!8H```TSP$`%BD``#C/`0`6*@``/,\!
M`!8K``!`SP$`%BP``$3/`0`6+@``2,\!`!8O``!,SP$`%C```%#/`0`6,0``
M5,\!`!8R``!8SP$`%C,``%S/`0`6-```8,\!`!8U``!DSP$`%C8``&C/`0`6
M-P``;,\!`!8Y``!PSP$`%CH``'3/`0`6.P``>,\!`!8\``!\SP$`%CT``(#/
M`0`6/@``A,\!`!8_``"(SP$`%D```(S/`0`600``D,\!`!9%``"4SP$`%D8`
M`)C/`0`61P``G,\!`!9*``"@SP$`%DL``*3/`0`63```J,\!`!9-``"LSP$`
M%DX``+#/`0`63P``M,\!`!90```(0"WIA@$`ZPA`O>@>_R_A!.`MY03@G^4.
MX(_@"/"^Y7R[`0``QH_B&\J,XGS[O.4`QH_B&\J,XG3[O.4`QH_B&\J,XFS[
MO.4`QH_B&\J,XF3[O.4`QH_B&\J,XES[O.4`QH_B&\J,XE3[O.4`QH_B&\J,
MXDS[O.4`QH_B&\J,XD3[O.4`QH_B&\J,XCS[O.4`QH_B&\J,XC3[O.4`QH_B
M&\J,XBS[O.4`QH_B&\J,XB3[O.4`QH_B&\J,XAS[O.4`QH_B&\J,XA3[O.4`
MQH_B&\J,X@S[O.4`QH_B&\J,X@3[O.4`QH_B&\J,XOSZO.4`QH_B&\J,XO3Z
MO.4`QH_B&\J,XNSZO.4`QH_B&\J,XN3ZO.4`QH_B&\J,XMSZO.4`QH_B&\J,
MXM3ZO.4`QH_B&\J,XLSZO.4`QH_B&\J,XL3ZO.4`QH_B&\J,XKSZO.4`QH_B
M&\J,XK3ZO.4`QH_B&\J,XJSZO.4`QH_B&\J,XJ3ZO.4`QH_B&\J,XISZO.4`
MQH_B&\J,XI3ZO.4`QH_B&\J,XHSZO.4`QH_B&\J,XH3ZO.4`QH_B&\J,XGSZ
MO.4`QH_B&\J,XG3ZO.4`QH_B&\J,XFSZO.4`QH_B&\J,XF3ZO.4`QH_B&\J,
MXESZO.4`QH_B&\J,XE3ZO.4`QH_B&\J,XDSZO.4`QH_B&\J,XD3ZO.4`QH_B
M&\J,XCSZO.4`QH_B&\J,XC3ZO.4`QH_B&\J,XBSZO.4`QH_B&\J,XB3ZO.4`
MQH_B&\J,XASZO.4`QH_B&\J,XA3ZO.4`QH_B&\J,X@SZO.4`QH_B&\J,X@3Z
MO.4`QH_B&\J,XOSYO.4`QH_B&\J,XO3YO.4`QH_B&\J,XNSYO.4`QH_B&\J,
MXN3YO.4`QH_B&\J,XMSYO.4`QH_B&\J,XM3YO.4`QH_B&\J,XLSYO.4`QH_B
M&\J,XL3YO.4`QH_B&\J,XKSYO.4`QH_B&\J,XK3YO.4`QH_B&\J,XJSYO.4`
MQH_B&\J,XJ3YO.4`QH_B&\J,XISYO.4`QH_B&\J,XI3YO.4`QH_B&\J,XHSY
MO.4`QH_B&\J,XH3YO.4`````\$`MZ4Q"G^4DT$WB%`"-Y1`0C>4,((WE/#*?
MY01`C^`#4)3G`#"5Y0P@C>(0$(WB%`"-XAPPC>68___K'"*?Y1PRG^4"()3G
M`P"4YP(0H.&!'`#K##*?Y0,PE.<`<-/E``!7XU4```K\,9_E`V"4YP``EN7=
M___K`""@X0XTT.4",(/C#C3"Y0``EN77___K%#"=Y0XDT.4%,(/B`2""XP<!
M<^,.),#E6@``B@,!H.%<___K`."@X00`H..L,9_E$,"=Y0,PC^``0)/EH#&?
MY0`0G.4#,(_@%""=Y0`0CN4$,([EC!&?Y8PQG^4!`%+C`S"/X`$0C^`,$([E
M\.\#Y?0/`^4(0([E!#",P@P0CL("P8S``P``V@0`D^0#`%SA!`"AY?O__QH`
M$*#C3&&?Y0W!@N(&8(_@Z`\6Y0`0C>4,$8[G.!&?Y0,@@N(.,*#A`1"/X'7_
M_^L`0%#B)```"B!AG^4&8(_@Z`\6Y1C__^L4`9_E&'"-X@<0H.$``(_@\!,`
MZP``4.,=```*_#"?Y0,PC^#H#Q/E^_[_ZUW__^L<()WE`#"5Y0,`4N$$`*#A
M)0``&B30C>+P0+WH'O\OX1+__^O(,)_E``!0XP,PC^#H#P/E'0``"NC^_^N(
M,)_E`V"4YP``EN6`___K?7;`Y9[__^KH#Q;E9___ZP!`H.'6___J[`\6Y0``
M4.,&```*\1L`Z]S__^IX,)_E>`"?Y0,0E.<``(_@*___ZVP`G^4'$*#A``"/
MX,(3`.L``%#C[`\&Y=#__PKP___JU/[_ZP$`H.,+___K4+@!`!@!```\`0``
M1`$``"0!```@`0``5+D!`&AU``!,=0``*-D!`.38`0``5P``M-@!`'AR``"(
MV`$`3-@!`#0!``#\<@``7'$```"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY2B@
MG^4D,(_B`Z"*X"#`G^4,P)KG!,`MY1@PG^4#,)KG%`"?Y0``FN?;_O_K-/__
MZXBU`0`,`0``.`$``$`!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P'5_O_J
M:+4!`"P!```T,)_E-`"?Y0,PC^```(_@`S"#X@`P0^`&`%/C(#"?Y0,PC^`>
M_R^1&""?Y0(PD^<``%/C'O\O`1/_+^'TM@$`\+8!`"RU`0`4`0``.!"?Y3@`
MG^4!$(_@``"/X``00>!!$:#AH1^!X"0PG^7!$+#A`S"/X![_+P$8()_E`C"3
MYP``4^,>_R\!$_\OX:BV`0"DM@$`W+0!`$P!``!,,)_E`S"/X``PT^4``%/C
M0#"?Y0,PC^`>_R\1$$`MZ30@G^4",)/G``!3XRPPGQ4#`)\71_[_&\G__^L!
M(*#C'#"?Y0,PC^``(,/E$$"]Z![_+^%<M@$`G+0!`!`!``#8M0$`'+8!`#P`
MG^4``(_@`#"0Y0``4^,P,)_E`S"/X````!K)___J)""?Y0(PD^<``%/C^O__
M"A!`+>D/X*#A$_\OX1!`O>C`___J&+,!`#2T`0!(`0```````/!/+>E$-9_E
MO]]-XA``C>4\)9_E<,"-X@,PC^!X@(#B#&"@X0!PH.,",)/G"$"-Y0Q0C>4,
M4*#A","@X6PPC>4`,)/E]#*-Y3C@@.($$)[E(32@X8@`C>@,`)WH(8R@X?\L
M`N(!I*#A`#"@XP$<H.$(((+A`2""X0`0H./_"`KB`"""X0``GN4',(/A`3"#
MX6`8(.`A%*#A".".XO\<P>-@%"'@#`!>X01PAN4(((;E##"&Y0`0AN408(;B
MXO__&@7`H.$G[HWB0!",X@,`D>AH,(SB#`"3Z``@(N`!,"/@$!",X@,`D>@`
M("+@`3`CX`,`G.@`("+@`3`CX*)/H.&#0(3A`#"@XP(`DN`(P(SB!""`X0X`
M7.%X((SE?#",Y>C__QH`0*#C`%"@XP0`H.$%$*#A$."=Y0BPCN(`#)OH(*"-
MY22PC>40L([B``R;Z`@`C>4,$(WE``R-Z'`0C>(#`)'H]\^/X@`8G.@`L)O@
M&)".X@`#F>@+`*#A``R=Z,``GN@H@(WE+)"-Y0B@*N`)L"O@()"-X@`#F>@!
MP*S@#!"@X0E?H.&FS:#AAS*@X0C`C>4H487AICV#X:?-H.$(3Z#A()".X@`#
MF>@(,(WE#,"-Y1A@C>4<<(WEAB*@X0APC>+``)?H"'"@X0!PE^!@@(WE9)"-
MY0&`J>`'`*#A"!"@X2"`C>*``9CH"X`(X`BPH.$HD(WB``.9Z`IP!^`'H*#A
M!4"$X0@PH.$$4*#A"4"@X0!PH.,"8(;A!B"@X0HP(^`#H*#A"T`DX`2PH.$'
M8*#A`@"0X`P`G>@`$*'B"D"0X#!0C>4T8(WE!2`BX`M0H>`8$(WB`P"1Z`<P
M(^`$L*#A!<"@X0(``.`#$`'@>'"-XL``E^A``(WE1!"-Y2H>C^(#`)'H!@"0
MX`<0H>``8*#A`7"@X0``H.,`$*#C.+"-Y3S`C>4`P*#C`""@X0$PH.$&@)C@
M!*"@X0RPH.%`4(WB,`"5Z`>0J>#``)WH!&`FX`5P)^`84(WB,`"5Z"3!H.$%
M'Z#A$""-Y10PC>4D$8'A0&"-Y41PC>40P(WE)<&@X1`0C>44P(WE!`^@X1!0
MC>(P`)7H`$"$X00`H.&+,J#AJCV#X:O-H.$,P(WE"#"-Y0A0C>(P`)7HBB*@
MX0)`A.$$(*#A`%"@XP!`H.%`<(WBP`"7Z`A@EN`)<*?@`@"6X``0I^(`@*#A
M`9"@X3@0C>(#`)'H!```X`40`>"`,(WB#`"3Z`!@H.$!<*#A&1Z/X@,`D>@"
M`)#@.$"-Y3Q0C>4#$*'@`$"@XP`PH.,0,(WE%$"-Y0@PC>4,0(WE`$"@XU``
MC>54$(WE,!"-X@,`D>@*`,#A"Q#!X0!@AN$!<(?A2&"-Y4QPC>4#`)WH4'"-
MXL``E^@&`)#@!%"@X0<0H>`!<*#A`&"@X84RH.$(0*#A0("-Y420C>6H/8/A
M!X"@X0L?H.$,$(WE*A&@X1`0C>4,$)WE*A&!X0P0C>40$)WE"Q^!X1`0C>4*
M'Z#A"!"-Y2L1H.$4$(WE$+"-X@`,F^A(P(WB`!B<Z`@0C>(#`)'H!K";X`C`
MK.`+8*#A"@"`X0QPH.$`H*#CA"*@X0,@@N$"D);@"L"@X0"@I^(X<(WBP`"7
MZ`5PQ^$`L*#A$)"-Y12@C>4'D*#A!&#&X0:`H.&(,(WB#`"3Z%1PC^+``)?H
M`F"6X`-PI^`&(*#A!S"@X4!PC>+``)?H#'`'X$"PC>5$P(WE";"'X05_H.$D
M<8?A)<&@X0APC>4,P(WE`&`&X`B@AN$$;Z#A"%"-XC``E>@#``#JF7F"6@``
M``#<LP$`&`$```9`A.$$8*#A,!"-X@,`D>@"`)#@`Q"AX#``C>4T$(WE,%"-
MXC``E>@0,(WB#`"3Z``PH.,*0)3@"U"EX`2@H.$%L*#A!D"@X0!0H..#DJ#A
MHIV)X8*"H.$(`(GA"$"-Y0Q0C>4`4)K@`&"KXC!0C>4T8(WE0&"-XF``EN@"
M4,7A`V#&X9"0C>(``YGH2%"-Y4Q@C>7]?X_BP`"7Z#BPC>(`#)OH"&"6X`EP
MI^`&H)K@!["KX#B@C>4\L(WE,*"-X@`&FN@`H*#C$!"-X@,`D>@(4(WB,`"5
MZ`F`H.$*D*#A2+"-X@`,F^@$``#@!1`!X`"@BN$!L(OA`W^@X1"@C>44L(WE
M(G&'X0)OH.$&0(?A$#"-X@P`D^@X<(WBP`"7Z`)@EN`#<*?@!B"@X0<PH.$`
M<*#CB;*@X:B]B^&(HJ#A"@"+X0BPC>(`#)OH`&"2X`=0H.$(H,KA`'"CX@FP
MR^$08(WE%'"-Y3B@C>4\L(WEF'"-XL``E^@QSH_B`!B<Z`:PF^`'P*S@"V"@
MX0QPH.$$,*#A0,"-X@`8G.@&L)O@,!"-X@,`D>@'P*S@,$"-Y310C>40<(WB
MP`"7Z$"PC>5$P(WE.+"-X@`,F^@#``#@!1`!X`"@BN$!L(OA`'"@XPO`H.$*
ML*#A.+"-Y3S`C>6'LJ#AIKV+X8:BH.$*((OA`*"@XPE?H.%`$(WB`P"1Z"A1
MA>$(3Z#A.)"-X@`#F>@(`)#@"1"AX`*0D.`%0(3A"E"@X0"@H>(XD(WE/*"-
MY9(_C^(,`)/HH)"-X@`#F>@(()+@"3"CX`*`H.$#D*#A,,"-X@`8G.@&L,OA
M!\#,X4"PC>5$P(WE"+"-X@`,F^@(H)K@";"KX$B@C>5,L(WE.*"-X@`&FN@`
MH*#C!#"@X1`0C>(#`)'H"8"@X0J0H.%`L(WB``R;Z`,``.`%$`'@`*"*X0&P
MB^$+P*#A"K"@X1!`C>444(WE"+"-Y0S`C>4'7Z#A2!"-X@,`D>@F487A!D^@
MX0APC>+``)?H!@"0X`<0H>``<*#C!4"$X0=0H.&)LJ#AJ+V+X8BBH.$*((OA
M`F"0X`!PH>((8(WE#'"-Y58?C^(#`)'HJ'"-XL``E^@0L(WB``R;Z`8`D.`(
MH,KA";#+X0<0H>!`H(WE1+"-Y0%PH.$XL(WB``R;Z`2@"N`%L`O@"B"@X0LP
MH.$PP(WB`!B<Z`"PF^`'P*S@2+"-Y4S`C>5`L(WB``R;Z`*@BN$#L(OA"'"-
MXL``E^@+P*#A`'"@XPJPH.$PL(WE-,"-Y8>RH.&FO8OAAJ*@X0H@B^$`H*#C
M.$"-Y3Q0C>4)7Z#A*%&%X4@0C>(#`)'H"$^@X3"0C>(``YGH"`"0X`D0H>`"
MD)#@!4"$X0I0H.$`H*'B,)"-Y32@C>5P,(_B#`"3Z+"0C>(``YGH"""2X`DP
MH^`"@*#A`Y"@X3C`C>(`&)SH!K#+X0?`S.%`L(WE1,"-Y1"PC>(`#)OH"*":
MX`FPJ^!(H(WE3+"-Y3"@C>(`!IKH`*"@XP0PH.$($(WB`P"1Z`F`H.$*D*#A
M!```Z@``H.&9>8):`````)EY@EH`````0+"-X@`,F^@#``#@!1`!X`"@BN$!
ML(OA$*"-Y12PC>4(0(WE#%"-Y0=?H.%($(WB`P"1Z"91A>$&3Z#A$'"-XL``
ME^@&`)#@!Q"AX`!PH..)LJ#AJ+V+X8BBH.$*((OA`F"0X`5`A.$'4*#A`'"A
MXA!@C>44<(WEB#!/X@P`D^BX<(WBP`"7Z`8@DN`',*/@`F"@X0-PH.$$,*#A
M"+"-X@`,F^@(H,KA";#+X4"@C>5$L(WE.,"-X@`8G.@&L)O@,!"-X@,`D>@'
MP*S@2+"-Y4S`C>5`L(WB``R;Z`,``.`%$`'@`*"*X0&PB^$0<(WBP`"7Z`O`
MH.$`<*#C"K"@X3BPC>4\P(WEA[*@X::]B^&&HJ#A"B"+X0"@H.,P0(WE-%"-
MY0E?H.%($(WB`P"1Z"A1A>$(3Z#A.)"-X@`#F>@(`)#@"1"AX`*0D.`%0(3A
M"E"@X0"@H>(XD(WE/*"-Y1<>3^(#`)'HP)"-X@`#F>@(`)#@"1"AX`&0H.$P
MP(WB`!B<Z`:PR^$'P,SA0+"-Y43`C>40L(WB``R;Z`2@"N`%L`O@"B"@X0LP
MH.$(L(WB``R;Z`"@FN`)L*O@$$"-Y110C>5(H(WE3+"-Y3B@C>(`!IKH`*"@
MXPF`H.$*D*#A0+"-X@`,F^@"H(KA`["+X0B@C>4,L(WE!U^@X4@0C>(#`)'H
M)E&%X09/H.$(<(WBP`"7Z`8`D.`'$*'@`'"@XXFRH.&HO8OAB**@X0H@B^$"
M8)#@!4"$X0=0H.$`<*'B"&"-Y0QPC>66/T_B#`"3Z,APC>+``)?H!B"2X`<P
MH^`"8*#A`W"@X00PH.$0L(WB``R;Z`B@RN$)L,OA0*"-Y42PC>4PP(WB`!B<
MZ`:PF^`X$(WB`P"1Z`?`K.!(L(WE3,"-Y4"PC>(`#)OH`P``X`40`>``H(KA
M`;"+X0APC>+``)?H"\"@X0!PH.,*L*#A,+"-Y33`C>6'LJ#AIKV+X8:BH.$*
M((OA`*"@XSA`C>4\4(WE"5^@X4@0C>(#`)'H*%&%X0A/H.$PD(WB``.9Z`@`
MD.`)$*'@`I"0X`5`A.$*4*#A`*"AXC"0C>4TH(WE#3U/X@P`D^C0D(WB``.9
MZ`@@DN`),*/@`H"@X0.0H.$XP(WB`!B<Z`:PR^$'P,SA0+"-Y43`C>40L(WB
M``R;Z`B@FN`)L*O@2*"-Y4RPC>4PH(WB``::Z`"@H.,$,*#A"!"-X@,`D>@)
M@*#A"I"@X4"PC>(`#)OH`P``X`40`>``H(KA`;"+X0O`H.$*L*#A"$"-Y0Q0
MC>40L(WE%,"-Y0=?H.$F487A2!"-X@,`D>@&3Z#A$'"-XL``E^@&`)#@!Q"A
MX`!PH.,%0(3A!U"@X8FRH.&HO8OAB**@X0H@B^$"8)#@`'"AXA!@C>44<(WE
M/QZ/X@,`D>C8<(WBP`"7Z`BPC>(`#)OH!@"0X`B@RN$)L,OA!Q"AX$"@C>5$
ML(WE`7"@X3"PC>(`#)OH!*`*X`6P"^`*(*#A"S"@X3C`C>(`&)SH`+";X`?`
MK.!(L(WE3,"-Y4"PC>(`#)OH`J"*X0.PB^$0<(WBP`"7Z`O`H.$`<*#C"K"@
MX3BPC>4\P(WEA[*@X::]B^&&HJ#A"B"+X0"@H.,P0(WE-%"-Y0E?H.%($(WB
M`P"1Z"A1A>$(3Z#A.)"-X@`#F>@(`)#@"1"AX`*0D.`%0(3A"E"@X0"@H>(X
MD(WE/*"-Y<(_C^(,`)/HX)"-X@`#F>@(()+@"3"CX`*`H.$#D*#A,,"-X@`8
MG.@&L,OA!\#,X4"PC>5$P(WE"+"-X@`,F^@(H)K@";"KX$B@C>5,L(WE.*"-
MX@`&FN@`H*#C!#"@X1`0C>(#`)'H"8"@X0J0H.%`L(WB``R;Z`,``.`%$`'@
M`*"*X0&PB^$(H(WE#+"-Y1!`C>444(WE!U^@X291A>%($(WB`P"1Z`9/H.$(
M<(WBP`"7Z`8`D.`'$*'@`'"@XXFRH.&HO8OAB**@X0H@B^$"8)#@!4"$X0=0
MH.$`<*'B"&"-Y0QPC>4B/H_B#`"3Z.APC>+``)?H!B"2X`<PH^`"8*#A`W"@
MX00PH.$0L(WB``R;Z`B@RN$)L,OA0*"-Y42PC>4PP(WB`!B<Z`:PF^`X$(WB
M`P"1Z`?`K.`X0(WE/%"-Y4BPC>5,P(WE0+"-X@`,F^@#``#@!1`!X`"@BN$!
ML(OA"'"-XL``E^@+P*#A`'"@XPJPH.$PL(WE-,"-Y8>RH.&FO8OAAJ*@X0H@
MB^$`H*#C"5^@X4@0C>(#`)'H*%&%X0A/H.$PD(WB``.9Z`@`D.`)$*'@`I"0
MX`5`A.$*4*#A`*"AXC"0C>4TH(WE3A^/X@,`D>CPD(WB``.9Z`@`D.`)$*'@
M`9"@X3C`C>(`&)SH!K#+X0?`S.%`L(WE1,"-Y0BPC>(`#)OH!*`*X`6P"^`*
M(*#A"S"@X1"PC>(`#)OH`*":X`FPJ^!(H(WE3+"-Y3"@C>(`!IKH`*"@XPF`
MH.$*D*#A0+"-X@`,F^@"H(KA`["+X1"@C>44L(WE"$"-Y0Q0C>4'7Z#A2!"-
MX@,`D>@F487A!D^@X1!PC>+``)?H!@"0X`<0H>``<*#CB;*@X:B]B^&(HJ#A
M"B"+X0BPC>(`#)OH`F"0X`5`A.$(H,KA!U"@X0FPR^$`<*'B$&"-Y11PC>5`
MH(WE1+"-Y?APC>+``)?H,+"/X@`,F^@&H)K@!["KX`MPH.$XP(WB`!B<Z`0P
MH.$*L)O@!\"LX!!PC>+``)?H`'"@XP4``.J9>8):`````)EY@EH`````H>O9
M;@`````P$(WB`P"1Z$BPC>5,P(WE0+"-X@`,F^@#``#@!1`!X`"@BN$!L(OA
M.*"-Y3RPC>6'LJ#AIKV+X8:BH.$*((OA`*"@XS!`C>4T4(WE"5^@X2A1A>%(
M$(WB`P"1Z`A/H.$XD(WB``.9Z`@`D.`)$*'@`I"0X`5`A.$*4*#A`*"AXCB0
MC>4\H(WE`9R-X@`#F>@PL(WB``R;Z`:@RN$'L,OA2*"-Y4RPC>7`P$_B`!B<
MZ`BPF^`)P*S@"X"@X0R0H.$(P(WB`!B<Z`BPF^`)P*S@.*"-X@`&FN@`H*#C
M!#"@X1`0C>(#`)'H$+"-Y13`C>4*L*#A":"@X4B0C>(``YGH0$"-Y410C>4#
M``#@!1`!X`=?H.$`@(CA`9")X291A>$&3Z#A)Q&@X0B`C>4,D(WE`7"%X05@
MA.$0$(WB`P"1Z%!@C>54<(WE"&"-XF``EN@%`)#@!A"AX%!@C>)@`);H`&"@
MXXN2H.&JG8GABH*@X0@@B>%84(WE7&"-Y0)@D.``<*'B2&"-Y4QPC>5"'XWB
M`P"1Z&MO3^)@`);H0$"-XA@`E.@`4)7@"C##X0M`Q.$!8*;@`X"@X020H.$&
M$*#A6$"-XA@`E.@X<(WBP`"7Z`4`H.$$<`?@`%"@XP!`H.,(0(WE#%"-Y3!0
MC>(P`)7H`V`&X$@PC>(,`)/H`#"@XP!`E.`!4*7@``"@XP`0H..#PJ#A#,"-
MY:+-H.$0`(WE%!"-Y1#`C>4,P)WEHLV,X0S`C>40P)WE"&"&X8/"C.$&0)3@
M"7"'X1#`C>6"PJ#A!U"EX`C`C>6CS:#A%,"-Y0L?H.$P0(WE-%"-Y0A0C>(P
M`)7H$'"-XL``E^@J$8'A"@^@X2N1H.$!H(#A";"!X01@AN$P$(WB`P"1Z%!0
MC>(P`)7H!@"0X#"@C>4TL(WE$7Z-XL``E^@*0"3@LZ]/X@`&FN@`$*'B!I"9
MX`>@JN`)8*#A"G"@X0"0H.,`H*#C4`"-Y500C>4`$*#C")"-Y0R@C>4)@*#A
M"I"@X4C`C>(`&)SH!+`KX`M`H.&!PJ#A#,"-Y:#-H.$0@(WE%)"-Y1#`C>4,
MP)WEH,V,X0S`C>40P)WE0+"-X@`,F^B!PHSA!J":X!#`C>6`PJ#A!["KX`C`
MC>4$0)K@H<V@X0.?H.$4P(WE`%"KXB*1B>$"CZ#A([&@X0APC>+``)?H.$"-
MY3Q0C>4+,(GA$%"-XC``E>@)((CA`I"@X0.@H.$X,(WB#`"3Z`9`A.$$()+@
M`#"CX@*PH.$#P*#A.)"-Y3R@C>5(L(WE3,"-Y0N@H.$`L*#C1G^-XL``E^CZ
M/T_B#`"3Z`8@DN`',*/@,%"-XC``E>@#<*#A`,"@XPLPH.$`L*#C`F"@X0H@
MH.$)0"3@`("@XP"0H.,(L(WE#,"-Y5#`C>(`&)SH@\*@X0S`C>6BS:#A$("-
MY120C>58H(WB``::Z!#`C>4,P)WEHLV,X0S`C>40P)WE@\*,X1#`C>4&D)G@
M@L*@X02P*^`(P(WE!Z"JX*/-H.$+0)G@%,"-Y0!0JN((<(WBP`"7Z$!`C>5$
M4(WE$%"-XC``E>@&0(3A0'"-XL``E^@$8);@!D"@X0!PI^('4*#A`9^@X2"1
MB>$`CZ#A(;&@X0D`B.$+$(GA.,"-X@`8G.A``(WE1!"-Y0`0H.,`L"O@!`"@
MX1)^C>+``)?H/YZ/X@`#F>A00(WE5%"-Y4A0C>(P`)7H!H"8X`>0J>`+0"3@
M"7"@X02@H.&!8J#AH&V&X09`H.$PD)WE#&"-Y0FPF."`8J#A"&"-Y0#`I^(*
M8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0-OH.$B88;A!H"@X11@
MC>4";Z#A$&"-Y2.1H.$0,(WB#`"3Z`1@F^`(((+A`'"LX@DP@^$&@*#A!Y"@
MX3`@C>4T,(WE2G^-XL``E^C-3X_B&`"4Z`8PD^`'0*3@!'"@X0!`H.,#8*#A
M!#"@X4"PC>(`#)OH4%"-XC``E>@"H"K@"D`DX$B`C>5,D(WE!*"@X3B0G>4)
ML);@@V*@X:AMAN$&0*#A#&"-Y8ABH.$`P*?B"&"-Y0I@F^``<*SB!K"@X0?`
MH.$(<(WBP`"7Z`1@AN$&0*#A`6^@X2!AAN$((*#A%&"-Y0:`H.$`;Z#A$&"-
MY01@F^``<*SB!D"@X0=0H.%00(WE5%"-Y0!0H.,AD:#A$!"-X@,`D>@)$('A
M,*"-X@`&FN@(`(#A`)`IX`F@H.$X`(WE/!"-Y040H.$$`*#A$WZ-XL``E^B.
MGX_B``.9Z$A0C>(P`)7H!H"8X`>0J>`*0"3@"7"@X02@H.&!8J#AH&V&X09`
MH.%`D)WE#&"-Y0FPF."`8J#A"&"-Y0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-
MXL``E^@$8(;A!D"@X0-OH.$B88;A!H"@X11@C>4";Z#A$&"-Y2.1H.$0,(WB
M#`"3Z`1@F^`(((+A`'"LX@DP@^$&@*#A0""-Y40PC>4'D*#A8T^/XA@`E.A.
M?XWBP`"7Z`8PD^`'0*3@!'"@X0!`H.,#8*#A!#"@X3BPC>(`#)OH4%"-XC``
ME>@"H"K@"D`DX$B`C>5,D(WE!*"@X3"0G>4)L);@@V*@X:AMAN$&0*#A#&"-
MY8ABH.$`P*?B"&"-Y0I@F^``<*SB!K"@X0?`H.$(<(WBP`"7Z`1@AN$&0*#A
M`6^@X2!AAN$((*#A!H"@X11@C>4`;Z#A$&"-Y01@F^`&0*#A(9&@X1`0C>(#
M`)'H`'"LX@D0@>%`H(WB``::Z`@`@.$'4*#A`)`IX`5]C>+``)?H,`"-Y300
MC>6@$(_B`P"1Z`8`D.`'$*'@`&"@X0%PH.$`$*#C!`"@X5!`C>544(WE2%"-
MXC``E>@)0"3@!*"@X3B0G>4)L);@@6*@X:!MAN$&0*#A#&"-Y8!BH.$(8(WE
M`,"GX@I@F^``<*SB!K"@X0?`H.$(<(WBP`"7Z`1@AN$&0*#A`V^@X2)AAN$&
M@*#A%&"-Y0)OH.$08(WE(Y&@X1`PC>(,`)/H!&";X`,``.JAZ]EN`````*'K
MV6X`````""""X0!PK.(),(/A!H"@X3@@C>4\,(WE!Y"@X2Q`3^(8`)3H4G^-
MXL``E^@&,)/@!T"DX`1PH.$`0*#C`V"@X00PH.$PL(WB``R;Z%!0C>(P`)7H
M`J`JX`I`).!(@(WE3)"-Y02@H.%`D)WE";"6X(-BH.&H;8;A!D"@X0Q@C>6(
M8J#A"&"-Y0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0%O
MH.$@88;A"""@X0:`H.$48(WE`&^@X1!@C>4$8)O@!D"@X2&1H.$0$(WB`P"1
MZ`!PK.()$('A.*"-X@`&FN@(`(#A!U"@X4``C>5$$(WE%7Z-XL``E^@`D"G@
M1A]/X@,`D>@&`)#@!Q"AX`!@H.$!<*#A`!"@XP0`H.%00(WE5%"-Y4A0C>(P
M`)7H"4`DX`2@H.$PD)WE";"6X(%BH.&@;8;A!D"@X0Q@C>6`8J#A`,"GX@A@
MC>4*8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0-OH.$B88;A!H"@
MX11@C>4";Z#A$&"-Y2.1H.$0,(WB#`"3Z`1@F^`(((+A`'"LX@DP@^$&@*#A
M!Y"@X3`@C>4T,(WE5G^-XL``E^@>3D_B&`"4Z`8PD^`'0*3@!'"@X0!`H.,#
M8*#A!#"@X4"PC>(`#)OH2("-Y4R0C>504(WB,`"5Z`*@*N`*0"3@.)"=Y02@
MH.$)L);@@V*@X:AMAN$&0*#A#&"-Y8ABH.$(8(WE`,"GX@I@F^``<*SB!K"@
MX0?`H.$(<(WBP`"7Z`1@AN$&0*#A`6^@X2!AAN$((*#A!H"@X11@C>4`;Z#A
M$&"-Y01@F^`&0*#A(9&@X1`0C>(#`)'H`'"LX@D0@>$PH(WB``::Z`@`@.$'
M4*#A.`"-Y3P0C>46?HWBP`"7Z`"0*>"Q'T_B`P"1Z`8`D.`'$*'@`&"@X0%P
MH.$`$*#C!`"@X5!`C>544(WE2%"-XC``E>@)0"3@!*"@X4"0G>4)L);@@6*@
MX:!MAN$&0*#A#&"-Y8!BH.$(8(WE`,"GX@I@F^``<*SB!K"@X0?`H.$(<(WB
MP`"7Z`1@AN$&0*#A`V^@X2)AAN$&@*#A%&"-Y0)OH.$08(WE(Y&@X1`PC>(,
M`)/H!&";X`@@@N$`<*SB"3"#X0:`H.$'D*#A0""-Y40PC>5:?XWBP`"7Z.-/
M3^(8`)3H!C"3X`=`I.`$<*#A`$"@XP-@H.$$,*#A.+"-X@`,F^A04(WB,`"5
MZ`*@*N`*0"3@2("-Y4R0C>4$H*#A,)"=Y0FPEN"#8J#AJ&V&X09`H.$,8(WE
MB&*@X0#`I^((8(WE"F";X`!PK.(&L*#A!\"@X0APC>+``)?H!&"&X09`H.$!
M;Z#A(&&&X0@@H.$&@*#A%&"-Y0!OH.$08(WE!&";X`9`H.$AD:#A$!"-X@,`
MD>@`<*SB"1"!X0=0H.$7?HWBP`"7Z$"@C>(`!IKH"`"`X3``C>4T$(WE`)`I
MX#\>C^(#`)'H!@"0X`<0H>``8*#A`7"@X0`0H.,$`*#A4$"-Y510C>5(4(WB
M,`"5Z`E`).`$H*#A.)"=Y0FPEN"!8J#AH&V&X09`H.$,8(WE@&*@X0A@C>4`
MP*?B"F";X`!PK.(&L*#A!\"@X0APC>+``)?H!&"&X09`H.$#;Z#A(F&&X0:`
MH.$48(WE`F^@X1!@C>4CD:#A$#"-X@P`D^@$8)O@""""X0!PK.(),(/A!H"@
MX3@@C>4\,(WE!Y"@X3-.C^(8`)3H7G^-XL``E^@&,)/@!T"DX`1PH.$`0*#C
M`V"@X00PH.$PL(WB``R;Z%!0C>(P`)7H`J`JX`I`).!(@(WE3)"-Y02@H.%`
MD)WE";"6X(-BH.&H;8;A!D"@X0Q@C>6(8J#A"&"-Y0#`I^(*8)O@`'"LX@:P
MH.$'P*#A"'"-XL``E^@$8(;A!D"@X0%OH.$@88;A"""@X0:`H.$48(WE`&^@
MX1!@C>4$8)O@!D"@X2&1H.$0$(WB`P"1Z`!PK.()$('A.*"-X@`&FN@(`(#A
M!U"@X0"0*>`&?8WBP`"7Z$``C>5$$(WED1^/X@,`D>@&`)#@!Q"AX`!@H.$!
M<*#A`!"@XP0`H.%00(WE5%"-Y4A0C>(P`)7H"4`DX`2@H.$PD)WE";"6X(%B
MH.&@;8;A!D"@X0Q@C>6`8J#A`,"GX@A@C>4*8)O@`'"LX@:PH.$'P*#A"'"-
MXL``E^@$8(;A!D"@X0-OH.$B88;A!H"@X11@C>4";Z#A$&"-Y2.1H.$0,(WB
M#`"3Z`1@F^`(((+A`'"LX@DP@^$&@*#A,""-Y30PC>4'D*#A84^/XA@`E.AB
M?XWBP`"7Z`8PD^`'0*3@!'"@X0!`H.,#8*#A!#"@X4"PC>(`#)OH4%"-XC``
ME>@"H"K@"D`DX$B`C>5,D(WE!*"@X3B0G>4)L);@@V*@X:AMAN$&0*#A#&"-
MY8ABH.$(8(WE`,"GX@I@F^``<*SB!K"@X0?`H.$(<(WBP`"7Z`1@AN$&0*#A
M`6^@X2!AAN$((*#A!H"@X11@C>4`;Z#A$&"-Y01@F^`&0*#A(9&@X1`0C>(#
M`)'H`'"LX@D0@>$PH(WB``::Z`@`@.$'4*#A.`"-Y3P0C>49?HWBP`"7Z`"0
M*>"8$(_B`P"1Z`8`D.`'$*'@`&"@X0%PH.$`$*#C!`"@X5!`C>544(WE2%"-
MXC``E>@)0"3@!*"@X4"0G>4)L);@@6*@X:!MAN$&0*#A#&"-Y8!BH.$`P*?B
M"&"-Y0I@F^``<*SB!K"@X0?`H.$(<(WBP`"7Z`1@AN$&0*#A`V^@X2)AAN$&
M@*#A%&"-Y0)OH.$08(WE(Y&@X08``.H``*#AH>O9;@````"AZ]EN`````-R\
M&X\`````$#"-X@P`D^@$8)O@""""X0!PK.(),(/A!H"@X0>0H.%`((WE1#"-
MY69_C>+``)?H2$!/XA@`E.@&,)/@!T"DX`1PH.$`0*#C`V"@X00PH.$XL(WB
M``R;Z$B`C>5,D(WE4%"-XC``E>@"H"K@"D`DX#"0G>4$H*#A";"6X(-BH.&H
M;8;A!D"@X0Q@C>6(8J#A"&"-Y0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-XL``
ME^@$8(;A!D"@X0%OH.$@88;A"""@X0:`H.$48(WE`&^@X1!@C>4$8)O@!D"@
MX2&1H.$0$(WB`P"1Z`!PK.()$('A0*"-X@`&FN@(`(#A!U"@X3``C>4T$(WE
M&GZ-XL``E^@`D"G@2Q]/X@,`D>@&`)#@!Q"AX`!@H.$!<*#A`!"@XP0`H.%0
M0(WE5%"-Y4A0C>(P`)7H"4`DX`2@H.$XD)WE";"6X(%BH.&@;8;A!D"@X0Q@
MC>6`8J#A"&"-Y0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@
MX0-OH.$B88;A%&"-Y0:`H.$";Z#A$&"-Y2.1H.$0,(WB#`"3Z`DP@^$#<*#A
M!)";X#!`C>(8`)3H`*"LX@=`).`XD(WE/*"-Y6J_C>(`#)OH!)"@X7]?3^(P
M`)7H"D"4X`M0I>`XP(WB`!B<Z`#`H.,(((+A`C`CX`.`H.$,,*#A`F"@X0L@
MH.%0L(WB``R;Z$A`C>5,4(WE"*`JX`FP*^!`P)WE4*"-Y52PC>5(L(WB``R;
MZ`R@FN"#PJ#AHLV,X0R`H.$08(WE%'"-Y0%_H.$@<8?A`&^@X2%1H.$'`(;A
M!1"'X0S`C>6"PJ#A`%"@X0%@H.$(P(WE4,"=Y0@0C>(#`)'H"`"`X0"`H.$0
M$(WB`P"1Z`"PJ^(,H)K@"%"-Y0Q@C>4`L*OB!A"!X0A@FN``<*OB.+"-X@`,
MF^@%`(#A`*`*X`A0C>(P`)7H`;`+X!`0C>(#`)'H0&"-Y41PC>4$``#@&WZ-
MXL``E^@%$`'@,5Y/XC``E>@&0)3@!U"EX`!@BN$!<(OA0+"-X@`,F^@`L*#C
M2$"-Y4Q0C>4X8(WE/'"-Y0H`H.$+$*#A,&"=Y4BPC>(`#)OH!J":X`"PJ^(+
MP*#A"K"@X0.?H.$BD8GA(U&@X3"PC>4TP(WE!3")X0*/H.$XP)WE"2"(X0.0
MH.$P0(WB&`"4Z`*`H.$,,)/@`$"DX@,@H.$$,*#A@;*@X0A0C>(P`)7HH+V+
MX8"BH.$*8(OA"*"$X0FPA>$(H(WE#+"-Y0:PDN``P*/B.+"-Y3S`C>5`,(WB
M#`"3Z`BPC>(`#)OH"$"-Y0Q0C>4#L`O@!#"@X05`H.$(,`/@"4`$X`*@"N`#
M(*#A!#"@X6Y_C>+``)?H_5^/XC``E>@&0)3@!U"EX`)@BN$#<(OA.+"-X@`,
MF^@`L*#C2$"-Y4Q0C>4*(*#A"S"@X4!@C>5$<(WE2+"-X@`,F^@08)WE!J":
MX`"PJ^(P@(WE-)"-Y0O`H.$!GZ#A"K"@X2"1B>$`CZ#A(5&@X0D`B.$%$(GA
M`("@X0&0H.$0L(WE%,"-Y1`0C>(#`)'H@[*@X4#`G>4P4(WB,`"5Z**]B^&"
MHJ#A#`"0X`I@B^$(H(3A";"%X1"@C>44L(WE`!"AX@:PD.``P*'B0+"-Y43`
MC>4X$(WB`P"1Z!"PC>(`#)OH`*`*X`&P"^`$`*#A!1"@X0=]C>+``)?H$("-
MY120C>4(``#@"1`!X+J?C^(``YGH!H"8X`>0J>``8(KA`7"+X4"PC>(`#)OH
M`+"@XTB`C>5,D(WE.&"-Y3QPC>4*`*#A"&"=Y0L0H.%(L(WB``R;Z`:@FN``
ML*OB"\"@X0JPH.$#GZ#A(I&)X2-1H.$(L(WE#,"-Y04PB>$"CZ#A.,"=Y0D@
MB.$#D*#A"$"-XA@`E.@"@*#A##"3X`!`I.(#(*#A!#"@X8&RH.$04(WB,`"5
MZ*"]B^&`HJ#A"F"+X0B@A.$)L(7A"*"-Y0RPC>4&L)+@`,"CXCBPC>4\P(WE
M0#"-X@P`D^@(L(WB``R;Z`.P"^`$,*#A!4"@X0@P`^`)0`3@`J`*X`,@H.$$
M,*#A<G^-XL``E^AW7X_B,`"5Z`9`E.`'4*7@`F"*X0-PB^$XL(WB``R;Z`"P
MH.-(0(WE3%"-Y0H@H.$+,*#A0&"-Y41PC>5(L(WB``R;Z#!@G>4&H)K@`+"K
MX@B`C>4,D(WE"\"@X0&?H.$*L*#A()&)X0"/H.$A4:#A"0"(X040B>$`@*#A
M`9"@X3"PC>4TP(WE"%"-XC``E>@P$(WB`P"1Z$#`G>6#LJ#AHKV+X8*BH.$,
M`)#@"F"+X0B@A.$)L(7A"*"-Y0RPC>4`$*'B!K"0X`#`H>)`L(WE1,"-Y3@0
MC>(#`)'H"+"-X@`,F^@`H`K@`;`+X`0`H.$%$*#A'7Z-XL``E^@P@(WE-)"-
MY0@``.`)$`'@T)"/X@`#F>@&@)C@!Y"IX`!@BN$!<(OA0+"-X@`,F^@`L*#C
M2("-Y4R0C>4X8(WE/'"-Y0H`H.$08)WE"Q"@X4BPC>(`#)OH!J":X`"PJ^(+
MP*#A"K"@X0.?H.$(0(WE#%"-Y2*1B>$C4:#A$+"-Y13`C>4%,(GA`H^@X3C`
MG>4)((CA`Y"@X1!`C>(8`)3H`H"@X0PPD^``0*3B`R"@X00PH.&!LJ#A,%"-
MXC``E>B@O8OA@**@X0I@B^$(H(3A";"%X1"@C>44L(WE!K"2X`0``.H``*#A
MW+P;CP````#<O!N/``````#`H^(XL(WE/,"-Y4`PC>(,`)/H$+"-X@`,F^@#
ML`O@!#"@X05`H.$(,`/@"4`$X`*@"N`#(*#A!#"@X79_C>+``)?H5%!/XC``
ME>@&0)3@!U"EX`)@BN$#<(OA.+"-X@`,F^@`L*#C2$"-Y4Q0C>4*(*#A"S"@
MX4!@C>5$<(WE2+"-X@`,F^@(8)WE!J":X`"PJ^(0@(WE%)"-Y0O`H.$!GZ#A
M"K"@X2"1B>$`CZ#A(5&@X0D`B.$%$(GA`("@X0&0H.$(L(WE#,"-Y1!0C>(P
M`)7H"!"-X@,`D>A`P)WE@[*@X:*]B^&"HJ#A#`"0X`I@B^$(H(3A";"%X0`0
MH>((H(WE#+"-Y0:PD.``P*'B0+"-Y43`C>4>?HWBP`"7Z#@0C>(#`)'H"+"-
MX@`,F^@`H`K@`;`+X`0`H.$%$*#A"("-Y0R0C>4(``#@"1`!X!:>3^(``YGH
M!H"8X`>0J>``8(KA`7"+X4"PC>(`#)OH`+"@XTB`C>5,D(WE.&"-Y3QPC>4*
M`*#A"Q"@X3!@G>5(L(WB``R;Z`:@FN``L*OB"\"@X0JPH.$#GZ#A(I&)X2-1
MH.$PL(WE-,"-Y04PB>$"CZ#A.,"=Y0D@B.$#D*#A,$"-XA@`E.@"@*#A##"3
MX`!`I.(#(*#A!#"@X8&RH.$(4(WB,`"5Z*"]B^&`HJ#A"F"+X0B@A.$)L(7A
M"*"-Y0RPC>4&L)+@`,"CXCBPC>4\P(WE0#"-X@P`D^@(L(WB``R;Z`A`C>4,
M4(WE`[`+X`0PH.$%0*#A"#`#X`E`!.`"H`K@`R"@X00PH.%Z?XWBP`"7Z)U?
M3^(P`)7H!D"4X`=0I>`"8(KA`W"+X3BPC>(`#)OH`+"@XTA`C>5,4(WE"B"@
MX4!@C>5$<(WE"S"@X1!@G>5(L(WB``R;Z`:@FN``L*OB,("-Y320C>4+P*#A
M`9^@X0JPH.$@D8GA`(^@X2%1H.$)`(CA!1")X0"`H.$!D*#A$+"-Y13`C>4P
M4(WB,`"5Z!`0C>(#`)'H0,"=Y8.RH.&BO8OA@J*@X0P`D.`*8(OA"*"$X0FP
MA>$`$*'B$*"-Y12PC>4&L)#@`,"AXA]^C>+``)?H0+"-Y43`C>4X$(WB`P"1
MZ!"PC>(`#)OH`*`*X`&P"^`$`*#A!1"@X1"`C>44D(WE"```X`D0`>`.G4_B
M``.9Z`:`F.`'D*G@`&"*X0%PB^%`L(WB``R;Z`"PH.-(@(WE3)"-Y3A@C>4\
M<(WE"@"@X0A@G>4+$*#A2+"-X@`,F^@&H)K@`+"KX@O`H.$*L*#A`Y^@X2*1
MB>$C4:#A"+"-Y0S`C>4%,(GA`H^@X3C`G>4)((CA`Y"@X0A`C>(8`)3H`H"@
MX0PPD^``0*3B`R"@X00PH.&!LJ#A$%"-XC``E>B@O8OA@**@X0I@B^$(H(3A
M";"%X0B@C>4,L(WE!K"2X`#`H^(XL(WE/,"-Y4`PC>(,`)/H"+"-X@`,F^@#
ML`O@!#"@X05`H.$(,`/@"4`$X`*@"N`#(*#A!#"@X7Y_C>+``)?H_5^/XC``
ME>@&0)3@!U"EX`)@BN$#<(OA.+"-X@`,F^@`L*#C2$"-Y4Q0C>4*(*#A0&"-
MY41PC>4+,*#A,&"=Y4BPC>(`#)OH!J":X`"PJ^((@(WE#)"-Y0O`H.$!GZ#A
M"K"@X2"1B>$`CZ#A(5&@X0D`B.$%$(GA`("@X0&0H.$PL(WE-,"-Y0A0C>(P
M`)7H0,"=Y3`0C>(#`)'H@[*@X:*]B^&"HJ#A#`"0X`I@B^$(H(3A";"%X0`0
MH>((H(WE#+"-Y0:PD.``P*'B0+"-Y43`C>4X$(WB`P"1Z`BPC>(`#)OH`*`*
MX`&P"^`$`*#A!1"@X0)\C>+``)?H"```X`A`C>4,4(WE"1`!X#"`C>4TD(WE
M+IZ/X@`#F>@&@)C@!Y"IX`!@BN$!<(OA0+"-X@`,F^@`L*#C2("-Y4R0C>4X
M8(WE/'"-Y0H`H.$08)WE"Q"@X4BPC>(`#)OH!J":X`"PJ^(+P*#A"K"@X0.?
MH.$BD8GA(U&@X1"PC>44P(WE!3")X0*/H.$XP)WE"2"(X0.0H.$00(WB&`"4
MZ`*`H.$,,)/@`$"DX@,@H.$$,*#A@;*@X3!0C>(P`)7HH+V+X8"BH.$*8(OA
M"*"$X0FPA>$0H(WE%+"-Y0:PDN``P*/B.+"-Y3S`C>5`,(WB#`"3Z!"PC>(`
M#)OH`[`+X`0PH.$%0*#A"#`#X`E`!.`"H`K@`R"@X00PH.&"?XWBP`"7Z'5?
MC^(P`)7H!D"4X`=0I>`"8(KA`W"+X3BPC>(`#)OH`+"@XTA`C>5,4(WE"B"@
MX4!@C>5$<(WE"S"@X0A@G>5(L(WB``R;Z`:@FN``L*OB$("-Y120C>4+P*#A
M`9^@X0JPH.$@D8GA`(^@X2%1H.$)`(CA!1")X0"`H.$!D*#A"+"-Y0S`C>40
M4(WB,`"5Z`@0C>(#`)'H0,"=Y8.RH.&BO8OA@J*@X0P`D.`*8(OA"*"$X0FP
MA>$(H(WE#+"-Y0`0H>(&L)#@`,"AXD"PC>5$P(WE.!"-X@,`D>@(L(WB``R;
MZ`"@"N`!L`O@!`"@X040H.$A?HWBP`"7Z`@``.`)$`'@"("-Y0R0C>7(D(_B
M``.9Z`:`F.`'D*G@`&"*X0%PB^%(@(WE3)"-Y3A@C>4\<(WE0+"-X@`,F^@`
ML*#C"@"@X0L0H.$P8)WE2+"-X@`,F^@&H)K@`+"KX@O`H.$*L*#A`Y^@X2*1
MB>$C4:#A,+"-Y33`C>4%,(GA`H^@X3C`G>4)((CA`Y"@X3!`C>(8`)3H`H"@
MX0PPD^``0*3B`R"@X00PH.&!LJ#A"%"-XC``E>B@O8OA@**@X0I@B^$(H(3A
M";"%X0B@C>4,L(WE!K"2X`0``.H``*#AW+P;CP````#<O!N/``````#`H^(X
ML(WE/,"-Y4`PC>(,`)/H"+"-X@`,F^@(0(WE#%"-Y0.P"^`$,*#A!4"@X0@P
M`^`)0`3@`J`*X`,@H.$$,*#AAG^-XL``E^A<4$_B,`"5Z`9`E.`'4*7@`F"*
MX0-PB^$XL(WB``R;Z`"PH.-(0(WE3%"-Y4!@C>5$<(WE"B"@X1!@G>4+,*#A
M2+"-X@`,F^@&H)K@`+"KXC"`C>4TD(WE"\"@X0&?H.$*L*#A()&)X0"/H.$A
M4:#A"0"(X040B>$`@*#A`9"@X1"PC>44P(WE,%"-XC``E>@0$(WB`P"1Z$#`
MG>6#LJ#AHKV+X8*BH.$,`)#@"F"+X0B@A.$)L(7A$*"-Y12PC>4`$*'B!K"0
MX`#`H>)`L(WE1,"-Y3@0C>(#`)'H$+"-X@`,F^@`H`K@`;`+X`0`H.$%$*#A
M(GZ-XL``E^@(``#@"1`!X!"`C>44D(WE6I]/X@`#F>@&@)C@!Y"IX`!@BN$!
M<(OA0+"-X@`,F^@`L*#C"@"@X0L0H.%(@(WE3)"-Y3A@C>4\<(WE"&"=Y4BP
MC>(`#)OH!J":X`"PJ^(+P*#A"K"@X0.?H.$BD8GA(U&@X0BPC>4,P(WE!3")
MX0*/H.$XP)WE"2"(X0.0H.$(0(WB&`"4Z`*`H.$,,)/@`$"DX@,@H.$$,*#A
M@;*@X1!0C>(P`)7HH+V+X8"BH.$*8(OA"*"$X0FPA>$(H(WE#+"-Y0:PDN``
MP*/B.+"-Y3S`C>5`,(WB#`"3Z`BPC>(`#)OH`[`+X`0PH.$%0*#A"#`#X`E`
M!.`"H`K@`R"@X00PH.&*?XWBP`"7Z)U?3^(P`)7H!D"4X`=0I>`"8(KA`W"+
MX3BPC>(`#)OH`+"@XTA`C>5,4(WE0&"-Y41PC>4*(*#A"S"@X3!@G>5(L(WB
M``R;Z`:@FN``L*OB"("-Y0R0C>4+P*#A`9^@X0JPH.$@D8GA`(^@X2%1H.$)
M`(CA!1")X0"`H.$!D*#A,+"-Y33`C>4(4(WB,`"5Z#`0C>(#`)'H0,"=Y8.R
MH.&BO8OA@J*@X0P`D.`*8(OA"*"$X0FPA>$(H(WE#+"-Y0`0H>(&L)#@`,"A
MXD"PC>5$P(WE.!"-X@,`D>@(L(WB``R;Z`"@"N`!L`O@!`"@X040H.$C?HWB
MP`"7Z`@``.`)$`'@,("-Y320C>4.G4_B``.9Z`:`F.`'D*G@`&"*X0%PB^%`
ML(WB``R;Z`"PH.-(@(WE3)"-Y0H`H.$+$*#A"$"-Y0Q0C>4X8(WE/'"-Y1!@
MG>5(L(WB``R;Z`:@FN``L*OB"\"@X0JPH.$#GZ#A(I&)X2-1H.$0L(WE%,"-
MY04PB>$"CZ#A.,"=Y0D@B.$#D*#A$$"-XA@`E.@"@*#A##"3X`!`I.(#(*#A
M!#"@X8&RH.$P4(WB,`"5Z*"]B^&`HJ#A"F"+X0B@A.$)L(7A$*"-Y12PC>4&
ML)+@`,"CXCBPC>4\P(WE0#"-X@P`D^@0L(WB``R;Z`.P"^`$,*#A!4"@X0@P
M`^`)0`3@`J`*X`,@H.$$,*#ACG^-XL``E^C]7X_B,`"5Z`9`E.`'4*7@`F"*
MX0-PB^$XL(WB``R;Z`"PH.-(0(WE3%"-Y0H@H.%`8(WE1'"-Y0LPH.$(8)WE
M2+"-X@`,F^@&H)K@`+"KXA"`C>44D(WE"\"@X0&?H.$*L*#A()&)X0"/H.$A
M4:#A"0"(X040B>$`@*#A`9"@X0BPC>4,P(WE$%"-XC``E>@($(WB`P"1Z$#`
MG>6#LJ#AHKV+X8*BH.$,`)#@"F"+X0B@A.$)L(7A$*"-Y12PC>4`$*'B!K"0
MX`#`H>((L(WE#,"-Y3@0C>(#`)'H$+"-X@`,F^@`H`K@`;`+X`0`H.$%$*#A
M"7V-XL``E^@(``#@"1`!X#B`C>4\D(WENI^/X@`#F>@&@)C@!Y"IX`!@BN$!
M<(OA"+"-X@`,F^@`L*#C2("-Y4R0C>4*`*#A"Q"@X4!@C>5$<(WE2+"-X@`,
MF^@P8)WE!J":X`"PJ^(+P*#A"K"@X0.?H.$00(WE%%"-Y2*1B>$C4:#A!3")
MX0*/H.$PL(WE-,"-Y0D@B.%`P)WE`Y"@X3!`C>(8`)3H`H"@X0PPD^``0*3B
M`R"@X00PH.&!LJ#A.%"-XC``E>B@O8OA@**@X0I@B^$(H(3A";"%X3B@C>4\
ML(WE!K"2X`#`H^((,(WB#`"3Z`0PH.$(,`/@,+"-Y33`C>62?XWBP`"7Z#BP
MC>(`#)OH0("-Y420C>4X0(WE/%"-Y0.`H.%V3X_B&`"4Z`8PD^`#8*#A`J`*
MX#`PC>(,`)/H`#"@XQ"0G>4'0*3@";"6X(-BH.&B;8;A`,"DX@9`H.$,8(WE
M"*"*X8)BH.$(8(WE"F";X`!PK.(&L*#A!\"@X0APC>+``)?H!&"&X09`H.$!
M;Z#A(&&&X0:`H.$48(WE`&^@X1!@C>4$8)O@!D"@X2&1H.$0$(WB`P"1Z`!P
MK.)`L(WB``R;Z`@`@.$)$('A!U"@X4@`C>5,$(WE)7Z-XL``E^@`H"K@1Q^/
MX@,`D>@&`)#@!Q"AX`!@H.$!<*#A`!"@XP0`H.%00(WE5%"-Y3!0C>(P`)7H
M"D`DX`2@H.$XD)WE";"6X(%BH.&@;8;A!D"@X0Q@C>6`8J#A`,"GX@A@C>4*
M8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0-OH.$B88;A!H"@X11@
MC>4";Z#A$&"-Y01@F^``<*SB!D"@X0=0H.$CD:#A$#"-X@P`D^@),(/A2*"-
MX@`&FN@(((+AEG^-XL``E^@"D"G@,""-Y30PC>5(,(_B#`"3Z`8@DN`',*/@
M6$"-Y5Q0C>4#<*#A!#"@X0!`H.,"8*#A`R"@X00PH.%04(WB,`"5Z`E`).`$
MH*#A!```Z@``H.'<O!N/`````-;!8LH`````0)"=Y0FPEN"#8J#AHFV&X09`
MH.$,8(WE@F*@X0A@C>4`P*?B"F";X`!PK.(&L*#A!\"@X0APC>+``)?H!&"&
MX09`H.$!;Z#A(&&&X11@C>4&@*#A`&^@X1!@C>4$8)O@`'"LX@9`H.$'4*#A
M4$"-Y510C>4`4*#C(9&@X1`0C>(#`)'H,+"-X@`,F^@(`(#A"1"!X3@`C>4\
M$(WE!1"@X0"@*N`$`*#A)GZ-XL``E^C`D$_B``.9Z%A0C>(P`)7H!H"8X`>0
MJ>`*0"3@"7"@X02@H.&!8J#AH&V&X09`H.%(D)WE#&"-Y0FPF."`8J#A"&"-
MY0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0-OH.$B88;A
M!H"@X11@C>4";Z#A$&"-Y2.1H.$0,(WB#`"3Z`1@F^`(((+A`'"LX@DP@^%`
M8(WE1'"-Y4@@C>5,,(WEFG^-XL``E^A=3T_B&`"4Z`8PD^`'0*3@`V"@X01P
MH.%`0(WB&`"4Z`!`H.,XH(WB``::Z`*0*>`#(*#A!#"@X5!0C>(P`)7H"4`D
MX`2@H.$PD)WE";"6X(-BH.&B;8;A!D"@X0Q@C>6"8J#A`,"GX@A@C>4*8)O@
M`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0%OH.$@88;A!H"@X11@C>4`
M;Z#A$&"-Y01@F^``<*SB!D"@X0=0H.%00(WE5%"-Y0!0H.,AD:#A$!"-X@,`
MD>A(L(WB``R;Z`@`@.$)$('A,`"-Y300C>4%$*#A`*`JX`0`H.$G?HWBP`"7
MZ)N?3^(``YGH0%"-XC``E>@&@)C@!Y"IX`I`).`)<*#A!*"@X8%BH.&@;8;A
M!D"@X3B0G>4,8(WE";"8X(!BH.$(8(WE`,"GX@I@F^``<*SB!K"@X0?`H.$(
M<(WBP`"7Z`1@AN$&0*#A`V^@X2)AAN$48(WE!H"@X0)OH.$08(WE!&";X`!P
MK.(&0*#A!U"@X2.1H.$0,(WB#`"3Z`@@@N$),(/A.""-Y3PPC>580(WE7%"-
MY00PH.$`0*#C,*"-X@`&FN@"D"G@":"@X0,@H.$$,*#AGG^-XL``E^C2GT_B
M``.9Z%!0C>(P`)7H!H"8X`>0J>`*0"3@"7"@X02@H.&#8J#AHFV&X09`H.%(
MD)WE#&"-Y0FPF.""8J#A`,"GX@A@C>4*8)O@`'"LX@:PH.$'P*#A"'"-XL``
ME^@$8(;A!D"@X0%OH.$@88;A%&"-Y0:`H.$`;Z#A$&"-Y01@F^``<*SB!D"@
MX0=0H.%00(WE5%"-Y0!0H.,AD:#A$!"-X@,`D>@XL(WB``R;Z`@`@.$)$('A
M0`"-Y400C>4%$*#A`*`JX`0`H.$*?8WBP`"7Z/V?C^(``YGH6%"-XC``E>@&
M@)C@!Y"IX`I`).`)<*#A!*"@X8%BH.&@;8;A!D"@X3"0G>4,8(WE";"8X(!B
MH.$(8(WE`,"GX@I@F^``<*SB!K"@X0?`H.$(<(WBP`"7Z`1@AN$&0*#A`V^@
MX2)AAN$&@*#A%&"-Y0)OH.$08(WE(Y&@X1`PC>(,`)/H!&";X`@@@N$`<*SB
M"3"#X3!@C>4T<(WE2""-Y4PPC>6B?XWBP`"7Z`U-C^(8`)3H!C"3X`=`I.`#
M8*#A!'"@X3!`C>(8`)3H`$"@XT"@C>(`!IKH`I`IX`,@H.$$,*#A4%"-XC``
ME>@)0"3@!*"@X3B0G>4)L);@@V*@X:)MAN$&0*#A#&"-Y8)BH.$(8(WE`,"G
MX@I@F^``<*SB!K"@X0?`H.$(<(WBP`"7Z`1@AN$&0*#A`6^@X2!AAN$48(WE
M!H"@X0!OH.$08(WE!&";X`!PK.(&0*#A!U"@X5!`C>544(WE`%"@XR&1H.$0
M$(WB`P"1Z$BPC>(`#)OH"`"`X0D0@>$X`(WE/!"-Y040H.$`H"K@!`"@X2E^
MC>+``)?HDI^/X@`#F>@P4(WB,`"5Z`:`F.`'D*G@"D`DX`EPH.$$H*#A@6*@
MX:!MAN$&0*#A0)"=Y0Q@C>4)L)C@@&*@X0#`I^((8(WE"F";X`!PK.(&L*#A
M!\"@X0APC>+``)?H!&"&X09`H.$#;Z#A(F&&X11@C>4&@*#A`F^@X1!@C>4$
M8)O@`'"LX@9`H.$'4*#A(Y&@X1`PC>(,`)/H""""X0DP@^&F?XWBP`"7Z#B@
MC>(`!IKH,""-Y30PC>580(WE7%"-Y00PH.$`0*#C`I`IX`F@H.$#(*#A!#"@
MX5N?C^(``YGH4%"-XC``E>@&@)C@!Y"IX`I`).`)<*#A!*"@X8-BH.&B;8;A
M!D"@X4B0G>4,8(WE";"8X()BH.$(8(WE`,"GX@I@F^``<*SB!K"@X0?`H.$(
M<(WBP`"7Z`1@AN$&0*#A`6^@X2!AAN$48(WE!H"@X0!OH.$08(WE!&";X`!P
MK.(&0*#A!U"@X5!`C>544(WE`%"@XR&1H.$0$(WB`P"1Z#"PC>(`#)OH"`"`
MX0D0@>%``(WE1!"-Y040H.$`H"K@!`"@X2I^C>+``)?HF)"/X@`#F>A84(WB
M,`"5Z`:`F.`'D*G@"D`DX`EPH.$$H*#A@6*@X:!MAN$&0*#A.)"=Y0Q@C>4)
ML)C@@&*@X0A@C>4`P*?B"F";X`!PK.(&L*#A!\"@X0APC>+``)?H!&"&X09`
MH.$#;Z#A(F&&X0:`H.$48(WE`F^@X1!@C>4CD:#A$#"-X@P`D^@$8)O@""""
MX0!PK.($``#J``"@X=;!8LH`````UL%BR@`````),(/A.&"-Y3QPC>5(((WE
M3#"-Y:I_C>+``)?H+$!/XA@`E.@&,)/@!T"DX`-@H.$$<*#A.$"-XA@`E.@`
M0*#C0*"-X@`&FN@"D"G@`R"@X00PH.%04(WB,`"5Z`E`).`$H*#A,)"=Y0FP
MEN"#8J#AHFV&X09`H.$,8(WE@F*@X0#`I^((8(WE"F";X`!PK.(&L*#A!\"@
MX0APC>+``)?H!&"&X09`H.$!;Z#A(&&&X0:`H.$48(WE`&^@X1!@C>4$8)O@
M`'"LX@9`H.$'4*#A(9&@X1`0C>(#`)'H4$"-Y510C>4`4*#C"`"`X0D0@>%(
ML(WB``R;Z#``C>4T$(WE!1"@X0"@*N`$`*#A*WZ-XL``E^A)GT_B``.9Z#A0
MC>(P`)7H!H"8X`>0J>`*0"3@"7"@X02@H.&!8J#AH&V&X09`H.%`D)WE#&"-
MY0FPF."`8J#A"&"-Y0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A
M!D"@X0-OH.$B88;A%&"-Y0:`H.$";Z#A$&"-Y01@F^``<*SB!D"@X0=0H.$C
MD:#A$#"-X@P`D^@(((+A"3"#X3@@C>4\,(WE6$"-Y5Q0C>4$,*#A`$"@XS"@
MC>(`!IKH`I`IX`F@H.$#(*#A!#"@X:Y_C>+``)?H`IQ/X@`#F>A04(WB,`"5
MZ`:`F.`'D*G@"D`DX`EPH.$$H*#A@V*@X:)MAN$&0*#A2)"=Y0Q@C>4)L)C@
M@F*@X0#`I^((8(WE"F";X`!PK.(&L*#A!\"@X0APC>+``)?H!&"&X09`H.$!
M;Z#A(&&&X11@C>4&@*#A`&^@X1!@C>4$8)O@`'"LX@9`H.$'4*#A4$"-Y510
MC>4`4*#C(9&@X1`0C>(#`)'H.+"-X@`,F^@(`(#A"1"!X4``C>5$$(WE!1"@
MX0"@*N`$`*#A"WV-XL``E^BUGT_B``.9Z%A0C>(P`)7H!H"8X`>0J>`*0"3@
M"7"@X02@H.&!8J#AH&V&X09`H.$PD)WE#&"-Y0FPF."`8J#A"&"-Y0#`I^(*
M8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A!D"@X0-OH.$B88;A!H"@X11@
MC>4";Z#A$&"-Y2.1H.$0,(WB#`"3Z`1@F^`(((+A`'"LX@DP@^$P8(WE-'"-
MY4@@C>5,,(WELG^-XL``E^CB3T_B&`"4Z`8PD^`'0*3@`V"@X01PH.$P0(WB
M&`"4Z`!`H.-`H(WB``::Z`*0*>`#(*#A!#"@X5!0C>(P`)7H"4`DX`2@H.$X
MD)WE";"6X(-BH.&B;8;A!D"@X0Q@C>6"8J#A"&"-Y0#`I^(*8)O@`'"LX@:P
MH.$'P*#A"'"-XL``E^@$8(;A!D"@X0%OH.$@88;A!H"@X11@C>4`;Z#A$&"-
MY2&1H.$$8)O@$!"-X@,`D>@`<*SB"`"`X0D0@>$&@*#A!Y"@X3I>C^(P`)7H
M+7Z-XL``E^@&0)3@!U"EX`5PH.$`4*#C.`"-Y3P0C>4$8*#A!1"@X4BPC>(`
M#)OH,%"-XC``E>@`H"K@"D`DX%"`C>54D(WE!*"@X4"0G>4)L);@@6*@X:AM
MAN$&0*#A#&"-Y8ABH.$`P*?B"&"-Y0I@F^``<*SB!K"@X0?`H.$(<(WBP`"7
MZ`1@AN$&0*#A`V^@X2)AAN$(`*#A!H"@X11@C>4";Z#A$&"-Y2.1H.$0,(WB
M#`"3Z`1@F^`(((+A`'"LX@DP@^$P8(WE-'"-Y3B@C>(`!IKHMG^-XL``E^A`
M((WE1#"-Y2M.C^(8`)3H!C"3X`=`I.`#8*#A!'"@X3!`C>(8`)3H`$"@XP*0
M*>`#(*#A!#"@X5!0C>(P`)7H"4`DX`2@H.%(D)WE";"6X(-BH.&B;8;A!D"@
MX0Q@C>6"8J#A"&"-Y0#`I^(*8)O@`'"LX@:PH.$'P*#A"'"-XL``E^@$8(;A
M!D"@X0%OH.$@88;A!H"@X11@C>4`;Z#A$&"-Y01@F^`A7H_B,`"5Z`!0H.,A
MD:#A$!"-X@,`D>@`<*SB"`"`X0D0@>$&@*#A!Y"@X2Y^C>+``)?H!D"4X$@`
MC>5,$(WE!&"@X040H.%`L(WB``R;Z#!0C>(P`)7H`*`JX%"`C>54D(WE"D`D
MX#B0G>4$H*#A";"6X(%BH.&H;8;A!D"@X0Q@C>6(8J#A"&"-Y0I@F^`&L*#A
M"'"-XL``E^@$8(;A!D"@X0-OH.$B88;A"`"@X0:`H.$48(WE`F^@X1!@C>4C
MD:#A$#"-X@P`D^@(((+A"3"#X0)@H.$#<*#A$&"-Y11PC>4$@)O@NC^-X@P`
MD^@0L(WB``R;Z$;/C^(`&)SH`%"@XP*PF^`+(*#A"$"@X4APC>+``)?H4,"-
MX@`8G.A`P)WEA9*@X0I@)N`,()+@J)V)X:7-H.$,P(WE!K`KX`B0C>4+L)+@
M"#"-X@P`D^B(@J#A""""X0*PF^`8,(WB#`"3Z`L@DN`!?Z#A`J"@X2`@C>(&
M`)+H`+"@XRB0C>(``YGH$#"=Y000D>`!0*#A`X"8X&`@C>(&`)+H2#"=Y2!Q
MA^$#$)'@`&^@X0P`G>@'8(;A!B"2X`$`H.$.8*#A`%"@XP"0H.,`$*#C`#"@
MXP`,CNALP)WE].*=Y0#`G.4,`%[A"$"&Y0Q0AN48@(;E')"&Y2``AN4D$(;E
M$""&Y10PAN4"```:O]^-XO!/O>@>_R_A&.O_Z];!8LH`````U#"?Y?!'+>D`
M<%#B`S"/X"\```K$()_E`C"3YP"0D^4``%GC*```"@!0U^4``%7C/0!5$P%0
MH!,`4*`#$P``&@!`F>4``%3C#0``"@&`H.$)8*#A!2"@X0<0H.$$`*#A@>O_
MZP``4.,"```:!3#4YST`4^,,```*!$"VY0``5./S__\:!`"@X?!'O>@>_R_A
M!U"@X0$P]>4``%/C/0!3$_O__QH'4$7@Y/__Z@E@1N!&8:#A`5"%X@!@B.4%
M0(3@!`"@X?!'O>@>_R_A"4"@X>O__^H'0*#AZ?__ZAAG`0!0`0``\$`MZ0S0
M3>(`4*#A#4"@X8!PG^6`,)_E!W"/X`-@E^<`,);E!#"-Y000H.$%`*#AN?__
MZP``4.,.```*7#"?Y0,PE^<`$)WE`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKK___J!""=Y0`PEN4#`%+A`@``&@S0C>+P
M0+WH'O\OX;?J_^LH9@$`&`$``%`!``#P3RWI`4"@X1"2G^40,I_E`"#1Y0F0
MC^`#4)GG/0!2XP%`@0(`,)7E%-!-X@!@H.$$`*#A##"-Y>'J_^L($(WB`'"@
MX08`H.&*___K`(!0XCX```K:ZO_K``!7X34``)K`,9_E"("=Y0.0F><(@:#A
M``#6Y0``4.,]`%`3`0"@$P``H`,%```*!@"@X0$P\.4``%/C/0!3$_O__QH&
M`$#@`G"'X@``A^``<)GELNK_ZP``4.,(`(?G50``"@`PUN4]`%/C``!3$P`@
MF>4($)WE`1&2YP%@AN(`,,'E!@``"@$@@>(!,-;D``!3XST`4Q,"$*#A`3#"
MY/G__QH],*#C`2"@X0`PP>4!,-3D``!3XP$PXN7[__\:``"@XPP@G>4`,)7E
M`P!2X3L``!H4T(WB\$^]Z![_+^$!($CB`3#4Y```4^,!,.+E^___&O'__^K0
M,)_E`Y"9YP"PF>4`H)OE``!:XR@```H((*#A"S"@X0```.H*(*#A!!"SY0``
M4>,!H(+B^O__&@,@@N("$:#AE#"?Y0,PC^``()/E``!2XPL```H+`*#A4NK_
MZP``4.,``(GE%@``"@`PH.$*@:#A`!"@XP$@BN("$8/G"*"-Y:;__^H!(*#C
M`0"@X0`@@^5EZO_K`#!0X@0PC>4(```*"H&@X0L0H.$((*#A'.K_ZP0PG>4`
M,(GE[/__Z@@0H./>___J``#@X[___^HLZO_KB&4!`!@!``!0`0``O&4!`/!/
M+>E$,9_E1"&?Y0,PC^`"4)/G`#"5Y7S03>(`<%#B=#"-Y0(```H`,-?E``!3
MXP8``!IT()WE`#"5Y0,`4N%!```:?-"-XO!/O>@>_R_A-^K_ZP!@4.+U__\*
M`*#@X_"PG^4(D(WB"["/X`8`H.&#ZO_K``!0XRP```H3,-#E+C!SX@4``!H4
M,-#E``!3X_7__PHN,'/B%3#0!0`P8Q(``%/C\/__"A-`@.('`*#A-^K_ZP"`
MH.$$`*#A-.K_ZP``B.`"`(#B'^K_ZP"`H.$+,*#A"B"@X0$0H.,$0(WE`'"-
MY3GJ_^L)(*#A"!"@X0,`H.-KZO_K`0!PXP@`H.$#```*&#"=Y0\Z`^(!"5/C
M"P``"NCI_^L(`*#AR^G_ZP8`H.%6ZO_K``!0X]+__QH&`*#A:NK_ZP<`H.',
MZ?_KN___ZJW__^OR___JU.G_ZV!C`0`8`0``R!T``'!`+>F$,)_EA""?Y0,P
MC^`"0)/G`%"@X0``E.5<ZO_K!1"@X5(O@.(#`*#C4NK_ZP``4.,"```*``"@
MXW!`O>@>_R_A``"4Y5'J_^M8,9#E#SH#X@$)4^,%```*``"4Y4OJ_^M8,9#E
M#SH#X@H*4^/P__\:!0"@X0(0H.,@ZO_K`0!PX@``H#-P0+WH'O\OX01B`0`@
M`0``\$<MZ?!0G^7P,)_E!5"/X`.`E><!VDWB"-!-X@"0H.'<`)_E`#"8Y0'*
MC>($<(WB!,",X@&@H.'(()_E!Q"@X0``C^``,(SEJNG_ZP``4.,@``#:"$"-
MX@%@0.(&0(3@!#!4Y0``4^,8```*`&"@X08@H.$O$*#C!P"@X??I_^L``%#C
M$P``"GPPG^4#,)7G``"3Y1CJ_^L&,*#A!R"@X0D0H.'\Z?_K`3J-X@0P@^(`
M()/E`#"8Y0,`4N$-```:`=J-X@C0C>+P1[WH'O\OX0``5N/E__\:+#"?Y0,P
ME><``)/E!.K_ZPH@H.$)$*#A?>G_Z^O__^ILZ?_K;&$!`!@!```$'```_P\`
M`"`!```00"WI-$"?Y30PG^4$0(_@`S"4YP``D^7SZ?_K)#"?Y200G^4#()3G
M(#"?Y0$0C^`#,(_@K>G_ZQ!`O>@>_R_A7&`!`"`!```<`0``&!L``,P:```0
M0"WI5#"?Y50@G^4#,(_@`D"3YPC03>(``)3EW>G_Z^'__^L``)3EVNG_ZP`@
MH.,P,)_E!""-Y2P0G^4L()_E`S"/X``PC>4"((_@`1"/X*;I_^L(T(WB$$"]
MZ![_+^$(8`$`(`$``*`=``#`&@``!!4``/!`+>G4,)_EU""?Y0,PC^`"8)/G
M`MI-XAS03>(`,);E`BJ-XA0@@N(`,(+E7^G_Z[`PG^4#,(_@"0"-Z*@PG^4,
M0(WB!`"@X0,PC^"<()_E`1"@XVKI_^L``%#C'```N@%:C>(84(7B"%!%X@0`
MH.$%$*#A`2J@XRCI_^L`0%#B$P``N@$`A.(\Z?_K`'!0X@0```H%$*#A!""@
MX?[H_^L`,*#C!##'YP(ZC>(4,(/B`""3Y0`PEN4#`%+A!P"@X04``!H"VHWB
M'-"-XO!`O>@>_R_A`'"@X_+__^K]Z/_KE%\!`!@!``"(&@``:!H```$0``#!
M___J\$\MZ72"G^5T,I_E"("/X`,PF.<!VDWB--!-X@!`H.%@`I_E&#"-Y0$J
MC>(`,)/E,)"-XBP@@N(!4*#A``"/X`@02>(`,(+ES?W_ZR\0H.,`8*#A!`"@
MX2+I_^L``%#C#P``"B`"G^4$$*#A``"/X"7^_^L$`*#A`3J-XBPP@^(`()/E
M&#"=Y0`PD^4#`%+A=@``&@':C>(TT(WB\$^]Z![_+^$$`*#A".G_Z]P1G^4`
MH*#A`1"/X`4`H.$YZ?_K`'!0XN;__PK$,9_E`S"/X!PPC>6\,9_E`S"/X"0P
MC>6T,9_E`S"/X!`PC>6L,9_E`S"/X!0PC>6D,9_E`S"/X"`PC>4`,-?EF+&?
MY0``4^,+L(_@.@``"@``5N,$```*!Q"@X08`H.&%Z/_K``!0XSH```H'`*#A
MY.C_ZP$P0.(#(-?G+P!2XP,PA^`%```:`!"@XP`0P^4!('/E+P!2XP$`0.+Z
M__\*`3"*X@``@^`!"E#CNO__JA`PG>4$4$GB`2J@XP$0H.,$,(WE`'"-Y0LP
MH.$(0(WE!0"@X=KH_^L$,9_E`W"8YP``E^4>Z?_K!1"@X5(O@.(#`*#C".G_
MZP``4.,%```:``"7Y1;I_^M8,9#E#SH#X@()4^,7```*%!"=Y0``H./NZ/_K
M`'"@X0``5^.:__\*`##7Y0``4^/$__\:``!6XPD```H<$)WE!@"@X4KH_^L`
M`%#C%```&B`0G>4``*#CWNC_ZP!PH.'N___J)'"=Y0$`H./)___J`1"@XP4`
MH.'3Z/_K``!0X^+__QI4`)_E!1"@X0``C^"I_?_K!0"@X:WH_^N!___J6NC_
MZQQPG>4!`*#CN?__ZIQ>`0`8`0``D!D``&P9```T&0``_!@``/`8```0&0``
M^!@``.P8``#<&```(`$``'P7````,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!
M,-+D``!3X_K__QH>_R_A<$`MZ0!`4.(O```*`%#4Y0``5>,L```*=>C_ZP$`
M0.(`((3@`@!4X0L``"H`,-3G+P!3XRX``!H!,$+B`P``Z@`0T^4O`%'C`3!#
MXB@``!H#`%3A`R"@X?C__QH"`%3A%P``"@$@0N($``#J`##2Y2\`4^,!,$+B
M`@``&@,@H.$"`%3A^/__.@0@0N`",(+B`0I3XQ,``(J4`)_E``"/X`10@.(!
M((+B!!"@X04`H.$!.J#C#^C_ZP4`H.%P0+WH'O\OX2\`5>,5```:`@"@XS7H
M_^L`,%#B+B"@$P,`H!&P(,,1]/__&@``H.-P0+WH'O\OX0$P0N(#``#J`!#3
MY2\`4>,!,$/BU?__"@,`5.$#(*#A^/__.@(`5.'0__\:Y___Z@P`G^4``(_@
M1>C_Z^'__^KD7`$`\!4``'!`+>G,P9_E#,"/X`S`C.+$49_E,-!-X@\`O.B\
M09_E!5"/X`C@C>($4)7G#P"NZ`\`O.@/`*[HI`&?Y0`@G.4`,)7E``"/X+`@
MSN$L,(WE_OS_ZXP!G^4``(_@^_S_ZX0!G^4``(_@^/S_ZWP!G^4``(_@]?S_
MZW0!G^4``(_@\OS_ZVP!G^4``(_@[_S_ZV0!G^4``(_@[/S_ZUQAG^5<`9_E
M!F"/X```C^#G_/_K!@"@X>7\_^M(`9_E``"/X.+\_^M``9_E``"/X-_\_^LX
M`9_E``"/X-S\_^LP`9_E``"/X-G\_^LH`9_E!$"-X@00H.$``(_@F_S_ZP`0
M4.(&`*`1^OS_&PP!G^4$$*#A``"/X)3\_^L`$%#B_`"?%0``CQ#R_/\;]`"?
MY000H.$``(_@C/S_ZP`04.(.```*X`"?Y0``C^#I_/_KV!"?Y=@`G^4!$(_@
M``"/X.3\_^LL()WE`#"5Y0,`4N$8```:,-"-XG!`O>@>_R_AL`"?Y000H.$`
M`(_@=_S_ZP`04.(#```*G`"?Y0``C^#4_/_KZ?__ZI`0G^4*(*#C`1"/X!D`
MC>('Z/_K``!0X^+__QIX`)_E(Q"-X@``C^#(_/_KW?__ZGOG_^L<%0``<%H!
M`!@!``"<%0``E!4``)`5``"0%0``C!4``)`5```@%0``C!4``'P5``"`%0``
M^!0``'05``!T%0``;!4``&05``!H%0``9!4``'`4``!P%0``L!0``"`5``",
M%```#!4``%P4```00"WIA!"?Y80@G^6$,)_E`1"/X`,PC^`"0)'G``"3Y0`P
ME.4(T$WB`0!PXP0PC>4&```*!""=Y0`PE.4#`%+A$0``&@C0C>(00+WH'O\O
MX40`G^4-$*#A``"/X#'\_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#
M'#"?Y0,PC^```(/EZ?__ZCSG_^L\6`$`&`$``)19`0"($P``*%D!`!!`+>D:
MY__K$^?_ZP``4.,``)`5$$"]Z![_+^'P3RWI1,&?Y411G^5$09_E!5"/X`S`
MC^`$0)7G!,",X@!@H.$/`+SH3-!-X@10H.$40(WE`$"@X2C@C>(/`*[H!P"<
MZ``PE>4``%3C!P".Z$0PC>4>```*_#"?Y?R0G^4#,(_@`+#@XP&@H.,)D(_@
M&#"-Y2Q0C>(D<(WB!@``Z@80H.'DYO_K``!0XQ@```H$0)7D``!4XPT```H'
M$*#A!`"@X>_[_^L`@%#B`@``"@`@V.4``%+C\/__&@0`H.$&$*#A2?S_ZP1`
ME>0``%3C\?__&A0PG>5$()WE`#"3Y0,`4N$8```:3-"-XO!/O>@>_R_A!@"@
MX2WG_^L<`(WE"`"@X2KG_^L<,)WE``"#X`(`@.(4Y__K&#"=Y0H0H.$$,(WE
M"("-Y0!@C>4),*#A"R"@X1P`C>4LY__K'!"=Y00`H.$I_/_KT/__ZMSF_^O4
M6`$`?%<!`!@!``!L$@``9!(``/!/+>D0NI_E@=Q-XD303>((RI_E+`"-Y0NP
MC^`,P)OG#%"@X?A)G^4$0(_@(#"$X@<`D^@%C8WB^#!(XBS@A.('`(/H#P"^
MZ##`C>7@P$CB#P"LZ`,`GNA$0(3B`P",Z`<`E.CL,$CB!P"#Z+0)G^4`P)7E
M@3R-XOQ@2.(\,(/B!A"@X0``C^``P(/EG/O_ZP!`4.("```*`##4Y0``4^,O
M`0`:=?__ZP!04.+L0$@"4```"@4`H.'DYO_K@`"@X0$`@.+/YO_K`##5Y0``
M4^,H`(WE#@``"@"@X.,!D*#C1'F?Y2A`G>4'<(_@`#"-Y00`H.$',*#A"B"@
MX0D0H.'AYO_K`3#UY0``4^,"0(3B]?__&N``&.4``%#C$@``"MQ`2.("``#J
M!`"4Y```4.,-```*!A"@X7'[_^L`4%#B^/__"@`PU>4``%/C]?__"K#\_^L`
M`%#C\O__"@4`H.'/YO_K`%!0XBX``!H`0*#C^'!(X@0QB.#X4!/E``!5XR<`
M``H`,-7E``!3XR0```H%`*#AG_S_ZP%`A.(``%#C!)&'X`H``!H$4)GD``!5
MXQL```H`,-7E``!3XQ@```H%`*#AD_S_ZP``4.,!0(3B]/__"@4`H.&QYO_K
M``!0X^/__PH`4*#A#@``ZJSF_^L``%#CY@``&@0`E.0``%#CW```"@80H.$]
M^__K`#!0XOC__PH`,-/E``!3X_7__PKQ___J`%"@XP4`H.&'YO_K*'"=Y0!`
MH.$'`*#A@^;_ZP!`A.`!2X3B!$"$X@0`H.%LYO_K`)"@X=`WG^70)Y_E`S"/
MX`0PC>7(-Y_E`B"/X`@@C>4#,(_@`"#@XP$0H.,,<(WE`%"-Y2@`C>5^YO_K
M"0"@X0<=H..'YO_K`0!PXR$```J0-Y_E`W";YP``E^6]YO_K*!"=Y5(O@.(#
M`*#CL^;_ZP!04.(I```*;#>?Y0,@F^<L,)WE``"2Y2@@G>4`,)/E`""-Y50G
MG^4!$*#C`B"/X'_F_^L`0*#C@3R-XCPP@^(`()/E,#"=Y0`PD^4#`%+A!`"@
MX1$"`!J!W(WB1-"-XO!/O>@>_R_A4^;_ZP`@D.41`%+CV?__"OPVG^4#$)OG
M+#"=Y0``D>4`,)/E!""-Y2@@G>4`((WEY":?Y0$0H.,"((_@8N;_ZP!`H./A
M___J``"7Y8OF_^M8,9#E#SH#X@$)4^//__\:``"7Y87F_^M@D9#EU>7_ZP``
M6>')__\:``"7Y7_F_^M8,9#E@SN@X:,[H.$'#5/CPO__&@0`H.$/YO_K`$"@
MX7@&G^4&$*#A``"/X,GZ_^L``%#C;0``"BPPG>4`8)/E+.;_ZP`0H.$&`*#A
MX/S_ZP!@4.)E```*!@"@X1#F_^L#`%#C`'"@X0P``-HP%I_E!`!`X@``AN`!
M$(_@I>7_ZP``4.,%```:!`!7XUP!``H'<(;@!3!7Y2\`4^-8`0`*8O[_ZP`0
M4.($```:!@"@X>;E_^L`,%#B-#"-Y4X``!K@%9_EX`6?Y0$0C^```(_@`OO_
MZ^SE_^O0-9_ET"6?Y0,PC^`H$)WE!#"-Y<0UG^4"((_@P+6?Y<"EG^7`E9_E
M"`"-Y0`0C>4,((WE`S"/X``@X.,!$*#C!`"@X>_E_^L';:#C"["/X`J@C^`)
MD(_@`(#@XP%PH.,0``#JY.7_ZP`PD.41`%/C$0``&L[E_^LH,)WE`5"%X@@`
MC>4`,(WE#%"-Y1"@C>4$D(WE"S"@X0@@H.$'$*#A!`"@X=?E_^L&$*#A!`"@
MX>#E_^L!`'#CZ?__"B@`G>5PY?_K)`6?Y000H.$``(_@S/K_ZP0`H.%._O_K
M9?__ZDS^_^L$`*#AS.7_ZP!`H.%@___J#0"@XZ'E_^OP5)_E*`"-Y5,PH.,%
M4(_@T/[_Z@!0H.'%_O_J+#"=Y0!@D^66___J!!!(X@)0H.,!8*#A`##@XQ$@
MX.,`4(WE+!"-Y8/E_^L&$*#A!B"@XS0`G>5#Y?_K!#!8Y0``4^,"```:`S!8
MY4,`4^,U`0`*`%"@XP`@H.,`,*#C`%"-Y30`G>5SY?_K``"@XP`0H./WOX_B
M``R;Z,"@".6\L`CE0*"@XST^C^(,`)/HH``(Y9P0".68``CEE!`(Y0]]C^+`
M`)?HR"`(Y<0P".7N'X_B`P"1Z.X_C^(,`)/HN&`(Y;1P".6P``CEK!`(Y:@@
M".6D,`CE4%`(Y3Q`C>5XD(WBD+!(X@(IH.,L$)WE-`"=Y13E_^L`0%#B5```
MVL0?H.&!,:#AI#Z#X83!H.$<,(WE&,"-Y1APC>+``)?H`'"@XZ`P2.(,`)/H
M`F"6X`<`4^$&`%(!!`"@X9@P2.(,`)/H`0``F@$@DN(`,*/BH,Z@X8'!C.&A
M'J#A(,"-Y200C>4@$(WB`P"1Z`(`D.`#$*'@`""@X0$PH.%0`!CE``!0XY@@
M".64,`CEH&`(Y9QP".4L```*0&!@X@8`5.$$8*"Q``"+X`8@H.$L$)WE].3_
MZU`P&.4#,(;@0`!3XU`P".7'__\:+#"=Y0D`H.$&0$3@!F"#X*[F_^L_`%3C
M$@``VD!`1.(_,,3C@%"#XC@PC>4%4(;@0'"&XD`01^(*(*#A"P"@X=[D_^M`
M<(?B"0"@X9_F_^L%`%?A]O__&C@PG>5`<(/B!V"&X#]`!.(&$*#A2#"@XP0@
MH.$+`*#A].3_ZU!`".6F___J+&"=Y>'__^HT`)WE/$"=Y6+E_^M_(.#CH&`8
MY:8QH.$_,`/B`1"#XI!02.(X`%'CF'`8Y0,@Q>>=``#*`0"%X#@@8>(`$*#C
M).7_ZS`P2.(G+*#A&#"-Y0-0H.$G.*#A"0"@X55P2.518$CE)W2@X5@@2.57
M,$CE)BR@X28XH.$F9*#A5G!(Y50@2.53,$CE4F!(Y6SF_^O(X!CEP``8Y2[(
MH.$N/*#A0>!(Y2[DH.&X$!CE0N!(Y2#LH.$]`$CE0.!(Y2#HH.$@!*#AL"`8
MY3X`2.4A#*#A0\!(Y3P`2.6HP!CE(0B@X3_@2.4Y$$CE(NR@X2$4H.$[`$CE
M-2!(Y2((H.&(D9_E(B2@X3H02.4W`$CE+!R@X2P(H.$V($CE+"2@X0"PX.,!
MH*#C1#!(Y3C@2.4QP$CE-!!(Y3,`2.4R($CE"9"/X$-@2.((<$CB````Z@$P
MUN0`,(WE!0"@X0DPH.$+(*#A"A"@X0)0A>++Y/_K!0!7X?7__QH``*#C$#&?
MY1@0G>4#,(_@""&?Y0@0C>4$,(WE*!"=Y?PPG^4"((_@`!"-Y0P@C>4#,(_@
M"`!(Y0`@X.,!$*#C!`"@X;?D_^OC_O_J+#"=Y01PD^4``%?CHO[_"@<`H.&A
MY/_K`P!0XY[^_YJT$)_E!`!`X@``A^`!$(_@-^3_ZP``4.,'8*`!EO[_Z@``
MH.&)J\WO``````$C16<`````_MRZF`````!V5#(0`````/#ATL,`````$%8!
M`!@!``!<5P$`R!```(`1```4#P``$!```/P/```@`0``*`$``!00```@#P``
M=!```)P.``#H#0``1`T``.@,``!8#P``*`X``"`.```@#P``G`P``/P+``#4
M#```/`D```0(``!L"@``/`D``.P(``!(!@``N`@``(0'``!`(&'B`0"%X``0
MH..&Y/_K"0"@X=_E_^L%`*#A.""@XP`0H..`Y/_K6O__Z@(P6.5!`%/CQO[_
M&@$P6.5#`%/CP_[_&@`PV.5(`%/CP/[_&@$PV.5%`%/CO?[_&@!0C>4T4)WE
M`##@XSD@X.,%`*#A,>3_ZP4`H.$L4)WE*2"@XP40H.'PX__KG#`?Y9P@'^4#
M,(_@*!"=Y00PC>6H,!_E`B"/X``0C>4,((WE"%"-Y0,PC^``(.#C`1"@XP0`
MH.%*Y/_K=O[_ZOWC_^OP3RWIQ".?Y<0SG^4"((_@`S"2YP`0D^4<T$WB%!"-
MY0PPC>6L,Y_E`V"2YP``EN6#Y/_K`$"@X0``EN6`Y/_K9##0Y9`#G^40$(WB
M93#$Y0``C^`($(WES_C_ZP``4.,"```*`##0Y3$`4^.Q```*[OO_ZP``EN5Q
MY/_K7!.?Y0LPH.,!(*#C`1"/X`GD_^L``%#C/0``"D0SG^4#,(_@]"\3Y1`P
MD.4!`%+C&)"3Y38``-H`4*#C*#.?Y2BSG^4#,(_@`4"@XP6`H.$+L(_@&*.?
MY0`PC>4*``#J$!"2Y0<`H.&<X__K``!0XR$``!H`,)WE]#\3Y0%`A.($`%/A
M`5"%XAX``-H``);E3.3_ZPD0H.$(,*#A!2"@X2KD_^L`$%#B?```"@`@D>4(
M,)+E\`\;Y0HP`^`!"U/C!'&0Y^7__PH``);E!!"-Y3SD_^L$$)WE`C"@XP@@
MH.$`$)'EO./_ZP`0H.$'`*#A>N/_ZP``4./=__\*=#*?Y0,PC^#T/Q/E`2!#
MX@4`4N%4```*``"6Y2KD_^M8$I_E`S"@XP$@H.,!$(_@PN/_ZP!`4.(+```*
M``"6Y2'D_^L0,)3E-"*?Y0`0D^4"((_@F./_ZQ`PE.4`,)/E"#"3Y0$%$^-J
M```:``"6Y17D_^L,$I_E`S"@XP$@H.,!$(_@K>/_ZP!`4.(+```*]`&?Y0@0
MG>4``(_@8/C_ZP!04.(``);E40``"@;D_^L0,)3E!2"@X0`0D^5^X__K``"6
MY0#D_^L`0*#A``"6Y?WC_^NT$9_E`2"@XP$0C^"KX__KJ"&?Y0`0H.$"((_@
M!`"@X7#C_^L``);E\N/_ZP`PH.-E,,#EB`&?Y0@0G>4``(_@0OC_ZWQ1G^4`
M`%#C!5"/X`!`H.'L#P7E)P``"@<=H.,$`*#AI^/_ZP$P@.(1`%#C`0!3$SD`
M`(H,,)WE%""=Y0`PD^4#`%+A,P``&AS0C>+P3[WH'O\OX0$`4^.H___:`4"@
MXR!1G^4%4(_@``"6Y=#C_^L)$*#A*>/_Z_0_%>4!0(3B!`!3X??__\J<___J
M^#"?Y0,PC^#T/Q/E`2!#X@4`4N&6__\:ZO__Z@$PT.4``%/C2___"DG__^KP
M#Q7E4?S_ZP``4.,`0*#A[`\%Y='__QJX`)_E``"/X'#C_^NTX__KK#"?Y0,P
MC^`0()3E\#\3Y0``DN4`$)/E;OG_ZZG__^H``);EJN/_ZQ`PE.4`$)/E=./_
MZX[__^H2X__K=#"?Y0,PC^#P'Q/E`#"@X6@`G^4$(*#A`!"1Y0``C^!7X__K
MM$H!`!@!```@`0``Z`4``&@'``#0:P$`K&L!`*!K`0``!"``\&H!`%0&```T
M!@``#`8``.`#``"T!0``O`4``%P#``#4:0$`>&D!`$QI`0#$!```^&@!`+QH
M`0"$!```<$`MZ0!0H.&M^O_K`##0Y0``4^,`0*#A!0``"@$`@.(O`%/C`$"@
M`0$PT.0``%/C^O__&H+[_^L``%7C``!0$P@```H`,-7E``!3XP4```HD$)_E
M!`"@X0$0C^"OXO_K``!4X0$```IP0+WH'O\OX04`H.%P0+WHJ?C_ZHP"```0
M0"WI'#"?Y1S`G^4#,(_@##"3YP``4^,`,),5S.+_ZQ!`O>@>_R_A!$8!`#`!
M``#P1RWI5&"?Y510G^4&8(_@!5"/X`5@1N``<*#A`8"@X0*0H.&(XO_K1F&P
MX0D```H`0*#C`4"$X@0PE>0)(*#A"!"@X0<`H.$/X*#A$_\OX00`5N'V__\:
M\$>]Z![_+^&D1`$`G$0!`![_+^$(0"WI"$"]Z![_+^$!``(`<&5R;'AS:2YC
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````)7,O)7,`
M```O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````
M4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!0
M15),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P``
M`%!!4E]#04-(10```%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"
M04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]
M```Q````4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!!4D=6`````!@```!P97)L
M`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`S-@```%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`
M5$U0`"]T;7``````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0
M051(`````$193$1?3$E"4D%265]0051(````4TA,24)?4$%42```979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC
M;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^
M9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A
M;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%2
M7T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D
M14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`[$[_?P$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````%P:``#T
M&0````````$````!`````0```-\!```!````Z@$```$```#T`0```0```$,"
M```!````G@,```$```"^`P``#````!`3```-````,(D``!D```!XS0$`&P``
M``0````:````?,T!`!P````$````]?[_;ZP!```%````B`D```8```"8`@``
M"@```"(%```+````$````!4``````````P```*S.`0`"``````(``!0````1
M````%P```!`1```1````Z`\``!(````H`0``$P````@````8`````````/O_
M_V\!```(_O__;X@/``#___]O`P```/#__V^J#@``^O__;Q<`````````````
M````````````````````````````````````````````A,T!````````````
M(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@
M$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3
M```@$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,`
M`"`3```@$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@$P``
M(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"`3```@
M$P``(!,``"`3```@$P``(!,``"`3```@$P``(!,``"R)````````````````
M``````````````````````````````30`0``````Q(@````````X%@``````
M```````````````````````$T`$`_____ZR,``"\C```Q(P``,R,``#4C```
MZ(P```````"DC```S(D```````"DB@``J(H``)B,``#4B0``H(P```````"$
MC```C(P```````#TC```1T-#.B`H1&5B:6%N(#8N,RXP+3(I(#8N,RXP(#(P
M,38Q,C(Y`$=#0SH@*$1E8FEA;B`V+C(N,2TU*2`V+C(N,2`R,#$V,3$R-`!!
M*0```&%E86)I``$?````!314``8""`$)`1($$P$4`14!%P,8`1D!&@(`+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=``N05)-+F%T=')I8G5T97,`````````````````````````````````
M````````````````````````"P````$````"````5`$``%0!```3````````
M```````!`````````!,````'`````@```&@!``!H`0``(```````````````
M!``````````A````!P````(```"(`0``B`$``"0```````````````0`````
M````-````/;__V\"````K`$``*P!``#L````!0`````````$````!````#X`
M```+`````@```)@"``"8`@``\`8```8````#````!````!````!&`````P``
M``(```"("0``B`D``"(%``````````````$`````````3@```/___V\"````
MJ@X``*H.``#>````!0`````````"`````@```%L```#^__]O`@```(@/``"(
M#P``8`````8````#````!`````````!J````"0````(```#H#P``Z`\``"@!
M```%``````````0````(````<P````D```!"````$!$``!`1`````@``!0``
M`!8````$````"````'P````!````!@```!`3```0$P``$```````````````
M!`````````!W`````0````8````@$P``(!,``!0#``````````````0````$
M````@@````$````&````.!8``#@6``#X<@`````````````(`````````(@`
M```!````!@```#")```PB0``#```````````````!`````````".`````0``
M``(````\B0``/(D``+1```````````````0`````````E@````$``'""````
M\,D``/#)```(````#0`````````$`````````*$````!`````@```/C)``#X
MR0``!```````````````!`````````"K````#@````,```!XS0$`>,T```0`
M``````````````0````$````MP````\````#````?,T!`'S-```$````````
M```````$````!````,,````!`````P```(#-`0"`S0``!```````````````
M!`````````#(````!@````,```"$S0$`A,T``"@!```&``````````0````(
M````T0````$````#````K,X!`*S.``!4`0`````````````$````!````-8`
M```!`````P````#0`0``T```7```````````````!`````````#<````"```
M``,```!<T`$`7-```!@0``````````````0`````````X0````$````P````
M`````%S0``!*```````````````!`````0```.H````#``!P``````````"F
MT```*@```````````````0`````````!`````P``````````````T-```/H`
2``````````````$`````````
